--[[
textureAndLabelData = {
	type = "textureAndLabel",
		
		image = "file/path.dds",
		getImageColor = function() 1,1,1,1 end,
		getImageWidth = function() return db.sizeX end,
		getImageHeight = function() return db.sizeY end,
		labelEnabled = true,
		label = "LabelText",
		labelFont = "file/path.tts",
		labelFontStyle = "none",
		getLabelFontSize = function() return db.size end,
		getLabelColor = function() return 1,1,1,1 end,
		getLabelFontOffsetX = function() return db.X end,
		getLabelFontOffsetY = function() return db.Y end,
		tooltip = "Image's tooltip text.",	--(optional)
		width = "full",	--or "half" (optional)
		reference = "MyAddonTexture"	--(optional) unique global reference to control
}
]]

local widgetVersion = 2
local LAM = LibStub("LibAddonMenu-2.0")
if not LAM:RegisterWidget("textureAndLabel", widgetVersion) then return end

local wm = WINDOW_MANAGER
local cm = CALLBACK_MANAGER
local tinsert = table.insert

local function UpdateValue(control)
	
	local texture = control.texture
	local label = control.label
	local data = control.data
	
	texture:SetDimensions(data.getImageWidth(), data.getImageHeight())
	texture:SetColor(data.getImageColor())
	
	if data.labelEnabled then	
		label:SetText(data.label)
		label:SetFont(data.labelFont .. "|" .. data.getLabelFontSize() .. "|" ..  data.labelFontStyle)
		label:SetColor(data.getLabelColor())
		label:ClearAnchors()
		label:SetAnchor(CENTER, texture, CENTER, data.getLabelFontOffsetX(), data.getLabelFontOffsetY())
	end
	
end

function LAMCreateControl.textureAndLabel(parent, data, controlName)

	local control = wm:CreateTopLevelWindow(controlName or data.reference)
	control:SetResizeToFitDescendents(true)
	control:SetParent(parent.scroll)
	
	local isHalfWidth = data.width == "half"
	if isHalfWidth then
		control:SetDimensionConstraints(250, 55, 250, 100)
		control:SetDimensions(250, 55)
	else
		control:SetDimensionConstraints(510, 30, 510, 100)
		control:SetDimensions(510, 30)
	end
	
	control.texture = wm:CreateControl(nil, control, CT_TEXTURE)
	local texture = control.texture
	
	texture:SetAnchor(CENTER)
	texture:SetDrawLayer(1)
	texture:SetTexture(data.image)
	
	if data.labelEnabled then
		control.label = wm:CreateControl(nil, control, CT_LABEL)
		local label = control.label
	
		label:SetText(data.label)
		label:SetHorizontalAlignment( CENTER )
		label:SetVerticalAlignment( CENTER )
		label:SetDrawLayer(2)
	end
	
	if data.tooltip then
		texture:SetMouseEnabled(true)
		texture.tooltipText = data.tooltip
		texture:SetHandler("OnMouseEnter", ZO_Options_OnMouseEnter)
		texture:SetHandler("OnMouseEnter", ZO_Options_OnMouseExit)
	end

	control.panel = parent.panel or parent	--if this is in a submenu, panel is its parent
	control.data = data
	
	control.UpdateValue = UpdateValue
	control:UpdateValue()
	
	if control.panel.data.registerForRefresh or control.panel.data.registerForDefaults then	--if our parent window wants to refresh controls, then add this to the list
		tinsert(control.panel.controlsToRefresh, control)
	end
	
	return control
end