--[[----------------------------------------------------------
	RadarMiniMap Functions
  ]]-----------------------------------------------------------

--Enable/Disable Addon
function RMM.ToggleAddon()
	if RMM.mainSet.active == true then
		RMM.mainSet.active = false
	else
		RMM.mainSet.active = true
	end
end
  
--Create Location Name
function RMM.CreateLocationName(map,loc)

	local function NameCutter(s)
		if not s then return "" end
		local first, _ = string.find(s, "^", nil, true)
		if not first then return s end
		return string.sub (s, 1, first-1)
	end

	local locfirst = NameCutter(map)
	local locsecond = NameCutter(loc)
	if RMM.mainSet.showLocationName then
		if locfirst ~= locsecond then
			RMM.c.locationNameFirst:SetText(locfirst)
			RMM.c.locationNameSecond:SetText(locsecond)
		else
			RMM.c.locationNameFirst:SetText(locfirst)
			RMM.c.locationNameSecond:SetText("")
		end
	else
		RMM.c.locationNameFirst:SetText("")
		RMM.c.locationNameSecond:SetText("")
	end
	
end

--Get Player
function RMM.PlayerPosChanged()
	
	if not RMM.player then RMM.player = {} end
	
	local player = {}
	local mapPlayerPositionNormalX, mapPlayerPositionNormalY, mapPlayerHeading = GetMapPlayerPosition('player')
	
	player.posX = mapPlayerPositionNormalX * RMM.map[RMM.mapName]["mapSizeWidth"] * RMM.mapZoom
	player.posY = mapPlayerPositionNormalY * RMM.map[RMM.mapName]["mapSizeHigh"] * RMM.mapZoom
	
	if RMM.mainSet.mapRotation then
		if RMM.mainSet.heading == "Player" then player.heading = -mapPlayerHeading else player.heading = -GetPlayerCameraHeading() end
	else
		if RMM.mainSet.heading == "Player" then player.heading = mapPlayerHeading else player.heading = GetPlayerCameraHeading() end
	end
	
	if RMM.player.posX ~= player.posX or RMM.player.posY ~= player.posY or RMM.player.heading ~= player.heading then 
		RMM.player = player
		return true
	else
		return false
	end
	
end

--Set Wheel Rotation
function RMM.SetWheelCir(rotate)

	if not RMM.mainSet.squareMap then
		if rotate == true then
			RMM.c.wheel:SetTextureRotation(RMM.player.heading,0.5,0.5)
		else
			RMM.c.wheel:SetTextureRotation(0,0.5,0.5)
		end
	else	
		RMM.RotateCompass(rotate)
	end
	
end

function RMM.DefaultCompass()
	for i = 1, ZO_CompassFrame:GetNumChildren() do
		local child = ZO_CompassFrame:GetChild(i)
		child:SetAlpha(RMM.mainSet.defaultCompass)
	end
end

--Rotate sqare compass
function RMM.RotateCompass(rotate)

	local num = RMM.c.compass:GetNumChildren()
	
	for i = 1, num do
		
		local child = RMM.c.compass:GetChild(i)
		local x = 0
		local y = 0
		local z = 0
		local xx = (RMM.mainSet.sizeX / 2) + RMM.mainSet.squareMapBorderCompass
		local yy = (RMM.mainSet.sizeY / 2) + RMM.mainSet.squareMapBorderCompass
		
		if rotate then
			local fx = child.x * math.sqrt((RMM.mainSet.sizeX^2)+(RMM.mainSet.sizeY^2))
			local fy = child.y * math.sqrt((RMM.mainSet.sizeX^2)+(RMM.mainSet.sizeY^2))
			x = (math.cos(-RMM.player.heading) * fx) - (math.sin(-RMM.player.heading) * fy)
			y = (math.sin(-RMM.player.heading) * fx) + (math.cos(-RMM.player.heading) * fy)
			z = math.sqrt((x^2)+(y^2))
		else
			local fx = child.x * math.sqrt((RMM.mainSet.sizeX^2)+(RMM.mainSet.sizeY^2))
			local fy = child.y * math.sqrt((RMM.mainSet.sizeX^2)+(RMM.mainSet.sizeY^2))
			x = (math.cos(0) * fx) - (math.sin(0.00001) * fy)
			y = (math.sin(0) * fx) + (math.cos(0.00001) * fy)
			z = math.sqrt((x^2)+(y^2))
		end
		
		if x > xx or x < -xx or y > yy or y < -yy then
			if x > xx or y > yy then
				if x/xx < y/yy then
					x = yy / y * x
					y = yy
				end
				if y/yy < x/xx then
					y = xx / x * y
					x = xx
				end
			end
			
			if x < -xx or y < -yy then
				if x/xx > y/yy then
					x = -yy / y * x
					y = -yy
				end		
				if y/yy > x/xx then
					y = -xx / x * y
					x = -xx
				end
			end
		end
		
		child:ClearAnchors()
		child:SetAnchor(CENTER, RMM.c.compass, CENTER, x, y)
		
	end
end

--Set Player Pin Rotation
function RMM.SetPPinCir(rotate)

	if rotate then
		RMM.c.map.ppin:SetTextureRotation(0,0.5,0.5)
	else
		RMM.c.map.ppin:SetTextureRotation(RMM.player.heading,0.5,0.5)
	end
	
end

--Register and Reregister Updates
function RMM.RegisterForUpdate(recall, name, rate, func)
	
	if recall then
		EVENT_MANAGER:UnregisterForUpdate(name)
		EVENT_MANAGER:RegisterForUpdate(name, rate, func)
	else
		EVENT_MANAGER:RegisterForUpdate(name, rate, func)
	end
	
end

function RMM.InRange()

	local inRangeX = true
	local inRangeY = true
	local inRange = true
	local mapPlayerPositionNormalX, mapPlayerPositionNormalY, playerHeading = GetMapPlayerPosition('player')
	if mapPlayerPositionNormalX < 0 or mapPlayerPositionNormalX > 1 then inRangeX = false end
	if mapPlayerPositionNormalY < 0 or mapPlayerPositionNormalY > 1 then inRangeY = false end
	if not inRangeX or not inRangeY then inRange = false end
	
	return inRange

end

--Hide Addon
function RMM.HideCheck()
		
	if RMM.mainSet.active then
		if ZO_KeybindStripControl:IsHidden() and ZO_InteractWindow:IsHidden() and ZO_GameMenu_InGame:IsHidden() then
			RMM.c:SetHidden(false)
			RMM.DefaultCompass()
		else
			RMM.c:SetHidden(true)
		end
	else
		RMM.c:SetHidden(true)
	end
	
end