--[[----------------------------------------------------------
	RadarMiniMap Keep Links
  ]]-----------------------------------------------------------
 
function RMM.CreateLinksAndLocks(linkNum)

	RMM.ClearLinks()
	RMM.ClearLocks()
	
	if RMM.mainSet.linkEnabled then
		local iLink = 0
		local iLock = 0
		
		for i = 1, linkNum do
			
			local link = ZO_WorldMapContainerKeepLinks:GetChild(i)
			if link and not link.alliance then
				RMM.CreateLinkControl(i)
				RMM.links[i]:SetTexture(link:GetTextureFileName())
				RMM.links[i]:SetThickness(RMM.mainSet.linkThick)
				RMM.links[i]:SetDrawLayer(2)
				RMM.links[i]:SetDrawLevel(10)
				RMM.links[i]:SetColor(link:GetColor())
				RMM.links[i].oldName = link:GetName()
				if link:GetAnchor() then RMM.links[i]:SetHidden(false) else RMM.links[i]:SetHidden(true) end
				RMM.links[i].sx = link.startNX
				RMM.links[i].sy = link.startNY
				RMM.links[i].ex = link.endNX
				RMM.links[i].ey = link.endNY
				
				iLink = iLink + 1
				RMM.oldLinks[iLink] = "RMM_KEEP_LINK_"..i
				
				for ii = 1, linkNum do
					
					local lock = ZO_WorldMapContainerKeepLinks:GetChild(ii)
					if lock then
						local _a, _b, parent = lock:GetAnchor()
						if parent then
							if parent:GetName() == RMM.links[i].oldName then
								local dx, dy = lock:GetDimensions()
								RMM.CreateLockControl(ii)
								RMM.locks[ii]:SetTexture(lock:GetTextureFileName())
								RMM.locks[ii]:SetDimensions(dx * RMM.mainSet.pinSize, dy * RMM.mainSet.pinSize)
								RMM.locks[ii]:SetColor(lock:GetColor())
								RMM.locks[ii]:SetDrawLayer(2)
								RMM.locks[ii]:SetDrawLevel(15)
								RMM.locks[ii]:SetAnchor(CENTER, RMM.links[i], CENTER, 0, 0)
								RMM.locks[ii]:SetHidden(RMM.links[i]:IsHidden())
								iLock = iLock + 1
								RMM.oldLocks[iLock] = "RMM_KEEP_LINK_LOCK_"..ii
							end
						end
					end
				end				
			end
		end
	end
end

function RMM.CreateLinkControl(i)
	
	if not WINDOW_MANAGER:GetControlByName("RMM_KEEP_LINK_"..i) then
		RMM.links[i] = WINDOW_MANAGER:CreateControl("RMM_KEEP_LINK_"..i, RMM.c.map, CT_LINE)
	else
		RMM.links[i] = WINDOW_MANAGER:GetControlByName("RMM_KEEP_LINK_"..i)
	end
	
end

function RMM.CreateLockControl(i)
	
	if not WINDOW_MANAGER:GetControlByName("RMM_KEEP_LINK_LOCK_"..i) then
		RMM.locks[i] = WINDOW_MANAGER:CreateControl("RMM_KEEP_LINK_LOCK_"..i, RMM.c.map, CT_TEXTURE)
	else
		RMM.locks[i] = WINDOW_MANAGER:GetControlByName("RMM_KEEP_LINK_LOCK_"..i)
	end
	
end

function RMM.ClearLinks()
	
	if not RMM.oldLinks then RMM.oldLinks = {} end

	for _,v in pairs(RMM.oldLinks) do
		local c = WINDOW_MANAGER:GetControlByName(v)
		if c then
				c:SetTexture("")
				c:SetThickness(0)
				c:SetColor(0,0,0,0)
		end
	end

	RMM.links = {}
	RMM.oldLinks = {}
	
end

function RMM.ClearLocks()
	
	if not RMM.oldLocks then RMM.oldLocks = {} end

	for _,v in pairs(RMM.oldLocks) do
		local c = WINDOW_MANAGER:GetControlByName(v)
		if c then
				c:SetTexture("")
				c:SetDimensions(0,0)
		end
	end

	RMM.locks = {}
	RMM.oldLocks = {}
	
end

function RMM.SetLinkPos(rotate)

	if not RMM.links then return end
	
	for k,v in pairs(RMM.links) do
	
		if rotate then
			local fsx = (RMM.links[k].sx * RMM.map[RMM.mapName]["mapSizeWidth"] * RMM.mapZoom) - RMM.player.posX
			local fsy = (RMM.links[k].sy * RMM.map[RMM.mapName]["mapSizeHigh"] * RMM.mapZoom) - RMM.player.posY
			local fex = (RMM.links[k].ex * RMM.map[RMM.mapName]["mapSizeWidth"] * RMM.mapZoom) - RMM.player.posX
			local fey = (RMM.links[k].ey * RMM.map[RMM.mapName]["mapSizeHigh"] * RMM.mapZoom) - RMM.player.posY
			sx = (math.cos(-RMM.player.heading) * fsx) - (math.sin(-RMM.player.heading) * fsy)
			sy = (math.sin(-RMM.player.heading) * fsx) + (math.cos(-RMM.player.heading) * fsy)
			ex = (math.cos(-RMM.player.heading) * fex) - (math.sin(-RMM.player.heading) * fey)
			ey = (math.sin(-RMM.player.heading) * fex) + (math.cos(-RMM.player.heading) * fey)
		else
			sx = (RMM.links[k].sx * RMM.map[RMM.mapName]["mapSizeWidth"] * RMM.mapZoom) - RMM.player.posX
			sy = (RMM.links[k].sy * RMM.map[RMM.mapName]["mapSizeHigh"] * RMM.mapZoom) - RMM.player.posY
			ex = (RMM.links[k].ex * RMM.map[RMM.mapName]["mapSizeWidth"] * RMM.mapZoom) - RMM.player.posX
			ey = (RMM.links[k].ey * RMM.map[RMM.mapName]["mapSizeHigh"] * RMM.mapZoom) - RMM.player.posY
		end
		
		RMM.links[k]:ClearAnchors()
		RMM.links[k]:SetAnchor(TOPLEFT, RMM.c, CENTER, sx, sy)
		RMM.links[k]:SetAnchor(BOTTOMRIGHT, RMM.c, CENTER, ex, ey)
		
	end
	
end