--[[----------------------------------------------------------
	RadarMiniMap Map
  ]]----------------------------------------------------------

	RMM.map = {}
	RMM.mapName = ""
	RMM.mapZoom = 1
	RMM.zoomChanged = false
 
--Update Map
function RMM.UpdateMap(mapName,zoom)
	
	if RMM.mapName ~= mapName or zoom ~= RMM.mapZoom then
		if RMM.map[mapName] then
			if RMM.mapName ~= mapName and zoom == RMM.mapZoom then RMM.WorldMapUpdate() else RMM.zoomChanged = true end
			RMM.mapName = mapName
			RMM.mapZoom = RMM.GetZoom()
			RMM.c.menuh.mapZoomSlider:SetValue(RMM.mapZoom)
			RMM.CreateMap()
		else
			RMM.SaveMap(mapName)
		end
	end
	
end

--SaveMap
function RMM.SaveMap(mapName)

	local texture = GetMapTileTexture()
	if not texture then return end
	local tileSizeWidth, tileSizeHigh = 1, 1
	
	if RMM.GetTextureSize(texture) then
		tileSizeWidth, tileSizeHigh = RMM.GetTextureSize(texture)
	else
		zo_callLater(function() RMM.SaveMap(mapName) end, 5)
		return
	end
	
	RMM.map[mapName] = {}
	RMM.map[mapName]["numTilesX"], RMM.map[mapName]["numTilesY"] = GetMapNumTiles()
	RMM.map[mapName]["numTiles"] = RMM.map[mapName]["numTilesX"] * RMM.map[mapName]["numTilesY"]
	RMM.map[mapName]["mapTyp"] = GetMapType()
	RMM.map[mapName]["mapContentType"] = GetMapContentType()
	RMM.map[mapName]["texture"] = RMM.TexturePathCutter(texture)
	RMM.map[mapName]["tileSizeWidth"], RMM.map[mapName]["tileSizeHigh"] = tileSizeWidth, tileSizeHigh
	RMM.map[mapName]["mapSizeWidth"] = RMM.map[mapName]["tileSizeWidth"] * RMM.map[mapName]["numTilesX"]
	RMM.map[mapName]["mapSizeHigh"] = RMM.map[mapName]["tileSizeHigh"] * RMM.map[mapName]["numTilesY"]
	
end
 
--Create Map
function RMM.CreateMap()
	
	RMM.ClearTiles()
	local iTile = 0
	
	for iY=1, RMM.map[RMM.mapName].numTilesY do
		RMM.mapTiles[iY] = {}
		for iX=1, RMM.map[RMM.mapName].numTilesX do
			RMM.CreateMapControl(iY,iX)
			RMM.mapTiles[iY][iX]:SetTexture(RMM.map[RMM.mapName]["texture"]..iTile..".dds")
			RMM.mapTiles[iY][iX]:SetDimensions(RMM.map[RMM.mapName]["tileSizeWidth"] * RMM.mapZoom, RMM.map[RMM.mapName]["tileSizeHigh"] * RMM.mapZoom)
			RMM.mapTiles[iY][iX]:SetDrawLayer(1)
			local x = (iX-0.5) * RMM.map[RMM.mapName]["tileSizeWidth"] * RMM.mapZoom
			local y = (iY-0.5) * RMM.map[RMM.mapName]["tileSizeHigh"] * RMM.mapZoom
			RMM.mapTiles[iY][iX]:ClearAnchors()
			RMM.mapTiles[iY][iX]:SetAnchor(CENTER, RMM.c.map, CENTER, x, y)
			iTile=iTile+1
			RMM.oldTiles[iTile] = "RMM_MAP_"..iX..iY
		end
	end
	
end

--Create Map Control
function RMM.CreateMapControl(iY,iX)
	
	if not WINDOW_MANAGER:GetControlByName("RMM_MAP_"..iX..iY) then
		RMM.mapTiles[iY][iX] = WINDOW_MANAGER:CreateControl("RMM_MAP_"..iX..iY, RMM.c.map, CT_TEXTURE)
	else
		RMM.mapTiles[iY][iX] = WINDOW_MANAGER:GetControlByName("RMM_MAP_"..iX..iY)
	end
	
end

--Remove Old
function RMM.ClearTiles()
	
	if not RMM.oldTiles then RMM.oldTiles = {} end
	for k,v in pairs(RMM.oldTiles) do
		local c = WINDOW_MANAGER:GetControlByName(v)
		if c then
			c:SetTexture("")
			c:SetDimensions(0,0)
			c:ClearAnchors()
		end
	end
	RMM.mapTiles = {}
	
end

function RMM.SetMapPos(rotate)

	for iY=1, RMM.map[RMM.mapName].numTilesY do
		for iX=1, RMM.map[RMM.mapName].numTilesX do
			local outX, outY = 0, 0
			if rotate then
				local x = ((iX-0.5) * (RMM.map[RMM.mapName]["tileSizeWidth"]) * RMM.mapZoom) - RMM.player.posX
				local y = ((iY-0.5) * (RMM.map[RMM.mapName]["tileSizeHigh"]) * RMM.mapZoom) - RMM.player.posY
				outX = (math.cos(-RMM.player.heading) * x) - (math.sin(-RMM.player.heading) * y)
				outY = (math.sin(-RMM.player.heading) * x) + (math.cos(-RMM.player.heading) * y)
				RMM.mapTiles[iY][iX]:SetTextureRotation(RMM.player.heading,0.5,0.5);
			else
				outX = ((iX-0.5) * (RMM.map[RMM.mapName]["tileSizeWidth"]) * RMM.mapZoom) - RMM.player.posX
				outY = ((iY-0.5) * (RMM.map[RMM.mapName]["tileSizeHigh"]) * RMM.mapZoom) - RMM.player.posY
				RMM.mapTiles[iY][iX]:SetTextureRotation(0,0.5,0.5)
			end
			RMM.mapTiles[iY][iX]:ClearAnchors()
			RMM.mapTiles[iY][iX]:SetAnchor(CENTER, RMM.c.map, CENTER, outX, outY)
		end
	end
	
end

function RMM.GetTextureSize(tileTexture)
	
	if not WINDOW_MANAGER:GetControlByName("RMM_TEMP_TEXTURE") then
		mapTile = WINDOW_MANAGER:CreateControl("RMM_TEMP_TEXTURE", RMM.c, CT_TEXTURE)
		mapTile:SetHidden(true)
	else
		mapTile = WINDOW_MANAGER:GetControlByName("RMM_TEMP_TEXTURE")
	end
	
	
	if mapTile:GetTextureFileName() ~= tileTexture then mapTile:SetTexture(tileTexture) end	

	if mapTile:IsTextureLoaded() then
		return mapTile:GetTextureFileDimensions()
	else
		return false
	end
	
end

function RMM.TexturePathCutter(s)

	if not s then return "" end
	local first, _ = string.find(s, "0", nil, true)
	if not first then return s end
	return string.sub (s, 1, first-1)
	
end

--Get Map Zoom
function RMM.GetZoom()

	if(RMM.map[RMM.mapName]) then
		local mapTyp = RMM.map[RMM.mapName]["mapTyp"]
		local mapContentType = RMM.map[RMM.mapName]["mapContentType"]
		local mapZoom = RMM.mainSet.zoom[mapTyp..mapContentType]
		return mapZoom
	else
		return 1
	end
	
end

--Set Map Zoom
function RMM.SetZoom(value)
	
	local mapTyp = RMM.map[RMM.mapName]["mapTyp"]
	local mapContentType = RMM.map[RMM.mapName]["mapContentType"]
	RMM.mainSet.zoom[mapTyp..mapContentType] = value
	RMM.c.menuh.mapZoomSlider.label:SetText("Map x "..value)

end

--Show Map Hidden
function RMM.WorldMapUpdate()
	ZO_WorldMap_UpdateMap()
	ZO_WorldMap:SetAlpha(0)
	ZO_WorldMap:SetHidden(false)
	zo_callLater(RMM.WorldMapReset, 100)
end

--Hide Map
function RMM.WorldMapReset()
	ZO_WorldMap:SetHidden(true)
	ZO_WorldMap:SetAlpha(1)
end