--[[----------------------------------------------------------
	RadarMiniMap Menu
  ]]----------------------------------------------------------


function RMM.CreateMenu()

	RMM.SetMenuData()
	RMM.lam:RegisterAddonPanel("RadarMiniMap", RMM.panelData)
	RMM.lam:RegisterOptionControls("RadarMiniMap", RMM.optionsTable)
	
end

function RMM.SetMenuData()
	RMM.panelData = {
		type = "panel",
		name = "Radar Mini Map",
		displayName = "|cFFFFB0Radar Mini Map",
		author = "DeathAngel",
		version = RMM.version,
		slashCommand = "/rmm",
		registerForRefresh = true,
		registerForDefaults = true,
	}

	RMM.optionsTable = {
		{
			type = "checkbox",
			name = "Enable/Disable Addon",
			tooltip = "Check to enable Addon.",
			getFunc = function() return RMM.mainSet.active end,
			setFunc = function(value) RMM.mainSet.active = value end,
			default = RMM.mainDefaults.active,
			width = "half",
		},
		{
			type = "dropdown",
			name = "Map Type",
			choices = {"RPG", "Tactical"},
			tooltip = "Switch between RPG / Tactical Map.",
			getFunc = function()
				if RMM.mainSet.squareMap then
					return "Tactical"
				else
					return "RPG"
				end
			end,
			setFunc = function(value)
				if value == "Tactical" then
					RMM.mainSet.squareMap = true
				else
					RMM.mainSet.squareMap = false
				end
				RMM.CreateUI()
			end,
			default = "RPG",
			width = "half",
		},
		{
			type = "checkbox",
			name = "Map Rotation",
			tooltip = "Check to enable Map Rotation.",
			getFunc = function() return RMM.mainSet.mapRotation end,
			setFunc = function(value)
				if value ~= RMM.mainSet.mapRotation then RMM.OptionChange("rotation") end
			end,
			default = RMM.mainDefaults.mapRotation,
			width = "half",
		},
		{
			type = "dropdown",
			name = "Map Heading",
			tooltip = "Switch between Camera / Player Rotation.",
			choices = {"Camera", "Player"},
			getFunc = function() return RMM.mainSet.heading end,
			setFunc = function(value)
				if value ~= RMM.mainSet.heading then RMM.OptionChange("heading") end
			end,
			default = RMM.mainDefaults.heading,
			width = "half",
		},
		{
			type = "slider",
			name = "Default Compass Transparency",
			tooltip = "Set default compass transparency.",
			min = 0,
			max = 1,
			step = 0.0625,
			getFunc = function() return RMM.mainSet.defaultCompass end,
			setFunc = function(value)
				RMM.mainSet.defaultCompass = value
				RMM.CreateUI()
			end,
			default = RMM.mainDefaults.defaultCompass,
			width = "full",
		},
		{
			type = "submenu",
			name = "|cFFFFB0Tactical Map",
			tooltip = "Settings for Tactical Map.",
			controls = {
				{
					type = "checkbox",
					name = "Square Map Compass",
					tooltip = "Check to enable square map compass.",
					getFunc = function() return RMM.mainSet.squareMapCompass end,
					setFunc = function(value)
						RMM.mainSet.squareMapCompass = value
						RMM.CreateUI()
					end,
					default = RMM.mainDefaults.squareMapCompass,
					width = "half",
				},
				{
					type = "checkbox",
					name = "Square Map Compass Border",
					tooltip = "Check to enable square map border for Compass.",
					getFunc = function() return RMM.mainSet.squareMapBorder end,
					setFunc = function(value)
						RMM.mainSet.squareMapBorder = value
						RMM.CreateUI()
					end,
					default = RMM.mainDefaults.squareMapBorder,
					width = "half",
				},
				{
					type = "slider",
					name = "Square Map Border Size",
					tooltip = "Set border Size.",
					min = 1,
					max = 50,
					step = 1,
					getFunc = function() return RMM.mainSet.squareMapBorderSize end,
					setFunc = function(value)
						RMM.mainSet.squareMapBorderSize = value
						RMM.CreateUI()
					end,
					default = RMM.mainDefaults.squareMapBorderSize,
					width = "half",
				},
				{
					type = "colorpicker",
					name = "Square Map Border Color",
					tooltip = "Set square map border color.",
					getFunc = function() return RMM.mainSet.squareMapBorderColor.r, RMM.mainSet.squareMapBorderColor.g, RMM.mainSet.squareMapBorderColor.b, RMM.mainSet.squareMapBorderColor.a end,
					setFunc = function(r,g,b,a)
						RMM.mainSet.squareMapBorderColor = {["r"] = r, ["g"] = g, ["b"] = b, ["a"] = a}
						RMM.CreateUI()
					end,
					default = RMM.mainDefaults.squareMapBorderColor,
					width = "half",
				},
				{
					type = "slider",
					name = "Compass Font Size",
					tooltip = "Set compass font size.",
					min = 6,
					max = 20,
					step = 1,
					getFunc = function() return RMM.mainSet.squareMapCompassFontSize end,
					setFunc = function(value)
						RMM.mainSet.squareMapCompassFontSize = value
						RMM.CreateUI()
					end,
					default = RMM.mainDefaults.squareMapCompassFontSize,
					width = "full",
				},
				{
					type = "dropdown",
					name = "Compass Font",
					tooltip = "Set compass font.",
					choices = RMM.GetFontChoices("Fonts"),
					getFunc = function() return RMM.mainSet.squareMapCompassFont end,
					setFunc = function(value)
						RMM.mainSet.squareMapCompassFont = value
						RMM.CreateUI()
					end,
					default = RMM.mainDefaults.squareMapCompassFont,
					width = "half",
				},
				{
					type = "dropdown",
					name = "Compass Font Type",
					tooltip = "Set compass font type.",
					choices = RMM.GetFontChoices("FontTypes"),
					getFunc = function() return RMM.mainSet.squareMapCompassFontType end,
					setFunc = function(value)
						RMM.mainSet.squareMapCompassFontType = value
						RMM.CreateUI()
					end,
					default = RMM.mainDefaults.squareMapCompassFontType,
					width = "half",
				},
				{
					type = "colorpicker",
					name = "Compass Font Color",
					tooltip = "Set compass font color.",
					getFunc = function() return RMM.mainSet.squareMapCompassFontColor.r, RMM.mainSet.squareMapCompassFontColor.g, RMM.mainSet.squareMapCompassFontColor.b, RMM.mainSet.squareMapCompassFontColor.a end,
					setFunc = function(r,g,b,a)
						RMM.mainSet.squareMapCompassFontColor = {["r"] = r, ["g"] = g, ["b"] = b, ["a"] = a}
						RMM.CreateUI()
					end,
					default = RMM.mainDefaults.squareMapCompassFontColor,
					width = "half",
				},
				{
					type = "slider",
					name = "Compass Offset",
					tooltip = "Set compass offset.",
					min = -50,
					max = 50,
					step = 1,
					getFunc = function() return RMM.mainSet.squareMapBorderCompass end,
					setFunc = function(value)
						RMM.mainSet.squareMapBorderCompass = value
						RMM.CreateUI()
					end,
					default = RMM.mainDefaults.squareMapBorderCompass,
					width = "half",
				},
				{
					type = "slider",
					name = "Map Alpha",
					tooltip = "Set map alpha.",
					min = 0,
					max = 1,
					step = 0.0625,
					getFunc = function() return RMM.mainSet.squareMapAlpha end,
					setFunc = function(value)
						RMM.mainSet.squareMapAlpha = value
						RMM.CreateUI()
					end,
					default = RMM.mainDefaults.squareMapAlpha,
					width = "full",
				},
				{
					type = "slider",
					name = "Border Icon Offset(pixel)",
					tooltip = "Border offset icons.",
					min = -50,
					max = 50,
					step = 1,
					getFunc = function() return RMM.mainSet.pixelBorder end,
					setFunc = function(value) RMM.mainSet.pixelBorder = value end,
					default = RMM.mainDefaults.pixelBorder,
					width = "full",
				},
			},
		},
		{
			type = "submenu",
			name = "|cFFFFB0RPG Map",
			tooltip = "Settings for RPG Map.",
			controls = {
				{
					type = "dropdown",
					name = "Wheel Texture",
					tooltip = "Set design of minimap wheel.",
					choices = RMM.GetTextureChoices("Wheel Texture"),
					getFunc = function() return RMM.mainSet.wheelAddon.."~"..RMM.mainSet.wheelTexture end,
					setFunc = function(value)
						local addon, texture = zo_strsplit("~",value)
						RMM.mainSet.wheelAddon = addon
						RMM.mainSet.wheelTexture = texture						
						RMM.CreateUI()
					end,
					default = RMM.mainDefaults.wheelAddon.."~"..RMM.mainDefaults.wheelTexture,
					width = "half",
				},
				{
					type = "dropdown",
					name = "Overlay Texture",
					tooltip = "Set design of minimap overlay.",
					choices = RMM.GetTextureChoices("Overlay Texture"),
					getFunc = function() return RMM.mainSet.overlayAddon.."~"..RMM.mainSet.overlayTexture end,
					setFunc = function(value)
						local addon, texture = zo_strsplit("~",value)
						RMM.mainSet.overlayAddon = addon
						RMM.mainSet.overlayTexture = texture	
						RMM.CreateUI()
					end,
					default = RMM.mainDefaults.overlayAddon.."~"..RMM.mainDefaults.overlayTexture,
					width = "half",
				},
				{
					type = "slider",
					name = "Border Icon Offset(percent)",
					tooltip = "Border offset icons.",
					min = -50,
					max = 50,
					step = 1,
					getFunc = function() return RMM.mainSet.percentBorder end,
					setFunc = function(value) RMM.mainSet.percentBorder = value end,
					default = RMM.mainDefaults.percentBorder,
					width = "full",
				},
			},
		},
		{
			type = "submenu",
			name = "|cFFFFB0Map Frame",
			tooltip = "Map Frame settings.",
			controls = {
				{
					type = "dropdown",
					name = "Quick Menu Anchor",
					tooltip = "Set quick menu anchor.",
					choices = {"AUTO", "BOTTOMLEFT", "TOPLEFT", "BOTTOMRIGHT", "TOPRIGHT"},
					getFunc = function() return RMM.mainSet.quickMenuAnchor end,
					setFunc = function(value)
						RMM.mainSet.quickMenuAnchor = value	
						RMM.MenuPos()
					end,
					default = RMM.mainDefaults.quickMenuAnchor,
					width = "full",
				},
				{
					type = "editbox",
					name = "Frame Position X",
					tooltip = "Frame Position X.",
					getFunc = function() return RMM.mainSet.positionX end,
					setFunc = function(text)
						RMM.mainSet.positionX = math.floor(tonumber(text)) or 100
						RMM.CreateUI()
					end,
					isMultiline = false,
					width = "half",
					default = RMM.mainDefaults.positionX,
				},
				{
					type = "editbox",
					name = "Frame Position Y",
					tooltip = "Frame Position Y.",
					getFunc = function() return RMM.mainSet.positionY end,
					setFunc = function(text)
						RMM.mainSet.positionY = math.floor(tonumber(text)) or 100
						RMM.CreateUI()
					end,
					isMultiline = false,
					width = "half",
					default = RMM.mainDefaults.positionY,
				},
				{
					type = "editbox",
					name = "Frame Size X",
					tooltip = "Frame Size X.",
					getFunc = function() return RMM.mainSet.sizeX end,
					setFunc = function(text)
						if RMM.mainSet.squareMap then
							RMM.mainSet.sizeX = math.floor(tonumber(text))
						else
							RMM.mainSet.sizeX = math.floor(tonumber(text)) or 256
							RMM.mainSet.sizeY = math.floor(tonumber(text)) or 256
						end
						RMM.CreateUI()
					end,
					isMultiline = false,
					width = "half",
					default = RMM.mainDefaults.sizeX,
				},
				{
					type = "editbox",
					name = "Frame Size Y",
					tooltip = "Frame Size Y.",
					getFunc = function() return RMM.mainSet.sizeY end,
					setFunc = function(text)
						if RMM.mainSet.squareMap then
							RMM.mainSet.sizeY = math.floor(tonumber(text))
						else
							RMM.mainSet.sizeX = math.floor(tonumber(text)) or 256
							RMM.mainSet.sizeY = math.floor(tonumber(text)) or 256
						end
						RMM.CreateUI()
					end,
					isMultiline = false,
					width = "half",
					default = RMM.mainDefaults.sizeY,
				},
			},
		},
		{
			type = "submenu",
			name = "|cFFFFB0Location Name",
			tooltip = "Location name settings.",
			controls = {
				{
					type = "checkbox",
					name = "Show Loction Name",
					tooltip = "Check to show location name.",
					getFunc = function() return RMM.mainSet.showLocationName end,
					setFunc = function(value)
						RMM.mainSet.showLocationName = value
						RMM.CreateUI()
					end,
					default = RMM.mainDefaults.showLocationName,
					width = "full",
				},
				{
					type = "slider",
					name = "Location Font Size",
					tooltip = "Set location font size.",
					min = 10,
					max = 20,
					step = 1,
					getFunc = function() return RMM.mainSet.locationFontSize end,
					setFunc = function(value)
						RMM.mainSet.locationFontSize = value
						RMM.CreateUI()
					end,
					default = RMM.mainDefaults.locationFontSize,
					width = "full",
				},
				{
					type = "dropdown",
					name = "Location Font",
					tooltip = "Set location font.",
					choices = RMM.GetFontChoices("Fonts"),
					getFunc = function() return RMM.mainSet.locationFont end,
					setFunc = function(value)
						RMM.mainSet.locationFont = value
						RMM.CreateUI()
					end,
					default = RMM.mainDefaults.locationFont,
					width = "half",
				},
				{
					type = "dropdown",
					name = "Location Font Type",
					tooltip = "Set location font type.",
					choices = RMM.GetFontChoices("FontTypes"),
					getFunc = function() return RMM.mainSet.locationFontType end,
					setFunc = function(value)
						RMM.mainSet.locationFontType = value
						RMM.CreateUI()
					end,
					default = RMM.mainDefaults.locationFontType,
					width = "half",
				},
				{
					type = "colorpicker",
					name = "Location Font Color",
					tooltip = "Set location font color.",
					getFunc = function() return RMM.mainSet.locationFontColor.r, RMM.mainSet.locationFontColor.g, RMM.mainSet.locationFontColor.b, RMM.mainSet.locationFontColor.a end,
					setFunc = function(r,g,b,a)
						RMM.mainSet.locationFontColor = {["r"] = r, ["g"] = g, ["b"] = b, ["a"] = a}
						RMM.CreateUI()
					end,
					default = RMM.mainDefaults.locationFontColor,
					width = "half",
				},
			},
		},
		{
			type = "submenu",
			name = "|cFFFFB0Map Zoom",
			tooltip = "Set Zoom for map types.",
			controls = {
				{
					type = "header",
					name = "Used Zoom Types",
					width = "full",
				},
				{
					type = "slider",
					name = "Zoom None-Dungeon",
					tooltip = "Zoom for Maptype.",
					min = 0.0625,
					max = 2.5,
					step = 0.0625,
					getFunc = function() return RMM.mainSet.zoom["02"] end,
					setFunc = function(value) RMM.mainSet.zoom["02"] = value end,
					default = RMM.mainDefaults.zoom["02"],
					width = "half",
				},
				{
					type = "slider",
					name = "Zoom Subzone-None",
					tooltip = "Zoom for Maptype.",
					min = 0.0625,
					max = 2.5,
					step = 0.0625,
					getFunc = function() return RMM.mainSet.zoom["10"] end,
					setFunc = function(value) RMM.mainSet.zoom["10"] = value end,
					default = RMM.mainDefaults.zoom["10"],
					width = "half",
				},
				{
					type = "slider",
					name = "Zoom Subzone-AvA",
					tooltip = "Zoom for Maptype.",
					min = 0.0625,
					max = 2.5,
					step = 0.0625,
					getFunc = function() return RMM.mainSet.zoom["11"] end,
					setFunc = function(value) RMM.mainSet.zoom["11"] = value end,
					default = RMM.mainDefaults.zoom["11"],
					width = "half",
				},
				{
					type = "slider",
					name = "Zoom Zone-None",
					tooltip = "Zoom for Maptype.",
					min = 0.0625,
					max = 2.5,
					step = 0.0625,
					getFunc = function() return RMM.mainSet.zoom["20"] end,
					setFunc = function(value) RMM.mainSet.zoom["20"] = value end,
					default = RMM.mainDefaults.zoom["20"],
					width = "half",
				},
				{
					type = "slider",
					name = "Zoom Zone-Dungeon",
					tooltip = "Zoom for Maptype.",
					min = 0.0625,
					max = 2.5,
					step = 0.0625,
					getFunc = function() return RMM.mainSet.zoom["22"] end,
					setFunc = function(value) RMM.mainSet.zoom["22"] = value end,
					default = RMM.mainDefaults.zoom["22"],
					width = "half",
				},
				{
					type = "slider",
					name = "Zoom Zone-AvA",
					tooltip = "Zoom for Maptype.",
					min = 0.0625,
					max = 2.5,
					step = 0.0625,
					getFunc = function() return RMM.mainSet.zoom["21"] end,
					setFunc = function(value) RMM.mainSet.zoom["21"] = value end,
					default = RMM.mainDefaults.zoom["21"],
					width = "half",
				},
				{
					type = "header",
					name = "Unused Zoom Types",
					width = "full",
				},
				{
					type = "slider",
					name = "Zoom None-None",
					tooltip = "Zoom for Maptype.",
					min = 0.0625,
					max = 2.5,
					step = 0.0625,
					getFunc = function() return RMM.mainSet.zoom["00"] end,
					setFunc = function(value) RMM.mainSet.zoom["00"] = value end,
					default = RMM.mainDefaults.zoom["00"],
					width = "half",
				},
				{
					type = "slider",
					name = "Zoom None-AvA",
					tooltip = "Zoom for Maptype.",
					min = 0.0625,
					max = 2.5,
					step = 0.0625,
					getFunc = function() return RMM.mainSet.zoom["01"] end,
					setFunc = function(value) RMM.mainSet.zoom["01"] = value end,
					default = RMM.mainDefaults.zoom["01"],
					width = "half",
				},
				{
					type = "slider",
					name = "Zoom Subzone-Dungeon",
					tooltip = "Zoom for Maptype.",
					min = 0.0625,
					max = 2.5,
					step = 0.0625,
					getFunc = function() return RMM.mainSet.zoom["12"] end,
					setFunc = function(value) RMM.mainSet.zoom["12"] = value end,
					default = RMM.mainDefaults.zoom["12"],
					width = "half",
				},
				{
					type = "slider",
					name = "Zoom World-None",
					tooltip = "Zoom for Maptype.",
					min = 0.0625,
					max = 2.5,
					step = 0.0625,
					getFunc = function() return RMM.mainSet.zoom["30"] end,
					setFunc = function(value) RMM.mainSet.zoom["30"] = value end,
					default = RMM.mainDefaults.zoom["30"],
					width = "half",
				},
				{
					type = "slider",
					name = "Zoom World-AvA",
					tooltip = "Zoom for Maptype.",
					min = 0.0625,
					max = 2.5,
					step = 0.0625,
					getFunc = function() return RMM.mainSet.zoom["31"] end,
					setFunc = function(value) RMM.mainSet.zoom["31"] = value end,
					default = RMM.mainDefaults.zoom["31"],
					width = "half",
				},
				{
					type = "slider",
					name = "Zoom World-Dungeon",
					tooltip = "Zoom for Maptype.",
					min = 0.0625,
					max = 2.5,
					step = 0.0625,
					getFunc = function() return RMM.mainSet.zoom["32"] end,
					setFunc = function(value) RMM.mainSet.zoom["32"] = value end,
					default = RMM.mainDefaults.zoom["32"],
					width = "half",
				},
				{
					type = "slider",
					name = "Zoom Alliance-None",
					tooltip = "Zoom for Maptype.",
					min = 0.0625,
					max = 2.5,
					step = 0.0625,
					getFunc = function() return RMM.mainSet.zoom["40"] end,
					setFunc = function(value) RMM.mainSet.zoom["40"] = value end,
					default = RMM.mainDefaults.zoom["40"],
					width = "half",
				},
				{
					type = "slider",
					name = "Zoom Alliance-AvA",
					tooltip = "Zoom for Maptype.",
					min = 0.0625,
					max = 2.5,
					step = 0.0625,
					getFunc = function() return RMM.mainSet.zoom["41"] end,
					setFunc = function(value) RMM.mainSet.zoom["41"] = value end,
					default = RMM.mainDefaults.zoom["41"],
					width = "half",
				},
				{
					type = "slider",
					name = "Zoom Alliance-Dungeon",
					tooltip = "Zoom for Maptype.",
					min = 0.0625,
					max = 2.5,
					step = 0.0625,
					getFunc = function() return RMM.mainSet.zoom["42"] end,
					setFunc = function(value) RMM.mainSet.zoom["42"] = value end,
					default = RMM.mainDefaults.zoom["42"],
					width = "half",
				},
				{
					type = "slider",
					name = "Zoom Cosmic-None",
					tooltip = "Zoom for Maptype.",
					min = 0.0625,
					max = 2.5,
					step = 0.0625,
					getFunc = function() return RMM.mainSet.zoom["50"] end,
					setFunc = function(value) RMM.mainSet.zoom["50"] = value end,
					default = RMM.mainDefaults.zoom["50"],
					width = "half",
				},
				{
					type = "slider",
					name = "Zoom Cosmic-AvA",
					tooltip = "Zoom for Maptype.",
					min = 0.0625,
					max = 2.5,
					step = 0.0625,
					getFunc = function() return RMM.mainSet.zoom["51"] end,
					setFunc = function(value) RMM.mainSet.zoom["51"] = value end,
					default = RMM.mainDefaults.zoom["51"],
					width = "half",
				},
				{
					type = "slider",
					name = "Zoom Cosmic-Dungeon",
					tooltip = "Zoom for Maptype.",
					min = 0.0625,
					max = 2.5,
					step = 0.0625,
					getFunc = function() return RMM.mainSet.zoom["52"] end,
					setFunc = function(value) RMM.mainSet.zoom["52"] = value end,
					default = RMM.mainDefaults.zoom["52"],
					width = "half",
				},				
			},
		},
		{
			type = "submenu",
			name = "|cFFFFB0Pins",
			tooltip = "Pin settings.",
			controls = {
				{
					type = "checkbox",
					name = "Show Pins",
					tooltip = "Check to enable pins.",
					getFunc = function() return RMM.mainSet.pinEnabled end,
					setFunc = function(value)
						if value ~= RMM.mainSet.pinEnabled then RMM.OptionChange("pin") end
					end,
					default = RMM.mainDefaults.pinEnabled,
					width = "half",
				},
				{
					type = "checkbox",
					name = "Show Pin Tooltips",
					tooltip = "Check to enable pin tooltips.",
					getFunc = function() return RMM.mainSet.tooltipsEnabled end,
					setFunc = function(value) RMM.mainSet.tooltipsEnabled = value end,
					default = RMM.mainDefaults.tooltipsEnabled,
					width = "half",
				},
				{
					type = "slider",
					name = "Pin Zoom",
					tooltip = "Set pin zoom.",
					min = 0.0625,
					max = 2.5,
					step = 0.0625,
					getFunc = function() return RMM.mainSet.pinSize end,
					setFunc = function(value)
						RMM.mainSet.pinSize = value;
						RMM.c.menuh.pinZoomSlider:SetValue(value)
						RMM.WorldMapUpdate()
					end,
					default = RMM.mainDefaults.pinSize,
					width = "full",
				},
				{
					type = "slider",
					name = "Harvest Map Pin Zoom Multi.",
					tooltip = "Set Harvest Map pin zoom multiplier.",
					min = 0.625,
					max = 4,
					step = 0.0625,
					getFunc = function() return RMM.mainSet.harvestMapZoom end,
					setFunc = function(value)
						RMM.mainSet.harvestMapZoom = value;
						RMM.WorldMapUpdate()
					end,
					default = RMM.mainDefaults.harvestMapZoom,
					width = "full",
				},
			},
		},
		{
			type = "submenu",
			name = "|cFFFFB0Pings",
			tooltip = "Ping settings.",
			controls = {
				{
					type = "colorpicker",
					name = "Player Ping Color",
					tooltip = "Player ping color.",
					getFunc = function() return RMM.mainSet.ping1Color.r,RMM.mainSet.ping1Color.g,RMM.mainSet.ping1Color.b,RMM.mainSet.ping1Color.a end,
					setFunc = function(r,g,b,a) RMM.mainSet.ping1Color = {["r"] = r, ["g"] = g, ["b"] = b, ["a"] = a}; RMM.WorldMapUpdate() end,
					default = RMM.mainDefaults.ping1Color,
					width = "full",
				},
				{
					type = "colorpicker",
					name = "?2? Ping Color",
					tooltip = "?2? ping color.",
					getFunc = function() return RMM.mainSet.ping2Color.r,RMM.mainSet.ping2Color.g,RMM.mainSet.ping2Color.b,RMM.mainSet.ping2Color.a end,
					setFunc = function(r,g,b,a) RMM.mainSet.ping2Color = {["r"] = r, ["g"] = g, ["b"] = b, ["a"] = a}; RMM.WorldMapUpdate() end,
					default = RMM.mainDefaults.ping2Color,
					width = "full",
				},
				{
					type = "colorpicker",
					name = "?3? Ping Color",
					tooltip = "?3? ping color.",
					getFunc = function() return RMM.mainSet.ping3Color.r,RMM.mainSet.ping3Color.g,RMM.mainSet.ping3Color.b,RMM.mainSet.ping3Color.a end,
					setFunc = function(r,g,b,a) RMM.mainSet.ping3Color = {["r"] = r, ["g"] = g, ["b"] = b, ["a"] = a}; RMM.WorldMapUpdate() end,
					default = RMM.mainDefaults.ping3Color,
					width = "full",
				},
			},
		},
		{
			type = "submenu",
			name = "|cFFFFB0Player Icon",
			tooltip = "Set color and size for player icon.",
			controls = {
				{
					type = "colorpicker",
					name = "Player Icon Color",
					tooltip = "Player icon color.",
					getFunc = function() return RMM.mainSet.playerPinColor.r, RMM.mainSet.playerPinColor.g, RMM.mainSet.playerPinColor.b, RMM.mainSet.playerPinColor.a end,
					setFunc = function(r,g,b,a) RMM.mainSet.playerPinColor = {["r"] = r, ["g"] = g, ["b"] = b, ["a"] = a}; RMM.c.map.ppin:SetColor(r,g,b,a) end,
					default = RMM.mainDefaults.playerPinColor,
					width = "half",
				},
				{
					type = "slider",
					name = "Player Icon Size",
					tooltip = "Player icon size in pixel.",
					min = 1,
					max = 32,
					step = 1,
					getFunc = function() return RMM.mainSet.playerPinSize end,
					setFunc = function(value) RMM.mainSet.playerPinSize = value; RMM.c.map.ppin:SetDimensions(value, value) end,
					default = RMM.mainDefaults.playerPinSize,
					width = "half",
				},
				{
					type = "textureAndLabel",
					image = "RadarMiniMap/asset/player.dds",
					getImageColor = function() return RMM.mainSet.playerPinColor.r, RMM.mainSet.playerPinColor.g, RMM.mainSet.playerPinColor.b, RMM.mainSet.playerPinColor.a end,
					getImageWidth = function() return RMM.mainSet.playerPinSize end,
					getImageHeight = function() return RMM.mainSet.playerPinSize end,
					labelEnabled = false,
					tooltip = "Image's tooltip text.",
					width = "full",
				},
			},
		},
		{
			type = "submenu",
			name = "|cFFFFB0Group Icons",
			tooltip = "Set color and size for group icons.",
			controls = {
				{
					type = "checkbox",
					name = "Border Group Icon",
					tooltip = "Border group icon.",
					getFunc = function() return RMM.mainSet.borderGroup end,
					setFunc = function(value) RMM.mainSet.borderGroup = value end,
					default = RMM.mainDefaults.borderGroup,
					width = "half",
				},
				{
					type = "checkbox",
					name = "Group Custom Icon",
					tooltip = "Group custom icon.",
					getFunc = function() return RMM.mainSet.groupCustomIcon end,
					setFunc = function(value) RMM.mainSet.groupCustomIcon = value end,
					default = RMM.mainDefaults.groupCustomIcon,
					width = "half",
				},
				{
					type = "checkbox",
					name = "Border Group Leader",
					tooltip = "Border group leader.",
					getFunc = function() return RMM.mainSet.borderGroupLeader end,
					setFunc = function(value) RMM.mainSet.borderGroupLeader = value end,
					default = RMM.mainDefaults.borderGroupLeader,
					width = "half",
				},
				{
					type = "checkbox",
					name = "Group Leader Custom Icon",
					tooltip = "Group leader custom icon.",
					getFunc = function() return RMM.mainSet.groupLeaderCustomIcon end,
					setFunc = function(value) RMM.mainSet.groupLeaderCustomIcon = value end,
					default = RMM.mainDefaults.groupLeaderCustomIcon,
					width = "half",
				},
			}
		},
		{
			type = "submenu",
			name = "|cFFFFB0Group Custom Icon",
			tooltip = "Set color and size for Group Icon.",
			controls = {
				{
					type = "colorpicker",
					name = "Group Icon Color",
					tooltip = "Group icon color.",
					getFunc = function() return RMM.mainSet.groupColor.r, RMM.mainSet.groupColor.g, RMM.mainSet.groupColor.b, RMM.mainSet.groupColor.a end,
					setFunc = function(r,g,b,a) RMM.mainSet.groupColor = {["r"] = r, ["g"] = g, ["b"] = b, ["a"] = a} end,
					default = RMM.mainDefaults.groupColor,
					width = "half",
				},
				{
					type = "slider",
					name = "Group Icon Size",
					tooltip = "Group icon size.",
					min = 1,
					max = 32,
					step = 1,
					getFunc = function() return RMM.mainSet.groupSize end,
					setFunc = function(value) RMM.mainSet.groupSize = value end,
					default = RMM.mainDefaults.groupSize,
					width = "half",
				},
				{
					type = "colorpicker",
					name = "Group Icon Text Color",
					tooltip = "Group icon text color",
					getFunc = function() return RMM.mainSet.groupTextColor.r, RMM.mainSet.groupTextColor.g, RMM.mainSet.groupTextColor.b, RMM.mainSet.groupTextColor.a end,
					setFunc = function(r,g,b,a) RMM.mainSet.groupTextColor = {["r"] = r, ["g"] = g, ["b"] = b, ["a"] = a} end,
					default = RMM.mainDefaults.groupTextColor,
					width = "half",
				},
				{
					type = "slider",
					name = "Group Icon Text Size",
					tooltip = "Group icon text size.",
					min = 1,
					max = 32,
					step = 1,
					getFunc = function() return RMM.mainSet.groupTextSize end,
					setFunc = function(value) RMM.mainSet.groupTextSize = value end,
					default = RMM.mainDefaults.groupTextSize,
					width = "half",
				},
				{
					type = "slider",
					name = "Group Icon Text Offset",
					tooltip = "Group icon text size.",
					min = -8,
					max = 8,
					step = 0.125,
					getFunc = function() return RMM.mainSet.groupTextOffsetX end,
					setFunc = function(value) RMM.mainSet.groupTextOffsetX = value end,
					default = RMM.mainDefaults.groupTextOffsetX,
					width = "half",
				},
				{
					type = "slider",
					name = "Group Icon Text Offset",
					tooltip = "Group icon text offset.",
					min = -8,
					max = 8,
					step = 0.125,
					getFunc = function() return RMM.mainSet.groupTextOffsetY end,
					setFunc = function(value) RMM.mainSet.groupTextOffsetY = value end,
					default = RMM.mainDefaults.groupTextOffsetY,
					width = "half",
				},
				{
					type = "textureAndLabel",
					image = "RadarMiniMap/asset/dot.dds",
					getImageColor = function() return RMM.mainSet.groupColor.r, RMM.mainSet.groupColor.g, RMM.mainSet.groupColor.b, RMM.mainSet.groupColor.a end,
					getImageWidth = function() return RMM.mainSet.groupSize end,
					getImageHeight = function() return RMM.mainSet.groupSize end,
					labelEnabled = true,
					label = "1",
					labelFont = "EsoUI/Common/Fonts/univers55.otf",
					getLabelFontSize = function() return RMM.mainSet.groupTextSize end,
					labelFontStyle = "none",
					getLabelColor = function() return RMM.mainSet.groupTextColor.r, RMM.mainSet.groupTextColor.g, RMM.mainSet.groupTextColor.b, RMM.mainSet.groupTextColor.a end,
					getLabelFontOffsetX = function() return RMM.mainSet.groupTextOffsetX end,
					getLabelFontOffsetY = function() return RMM.mainSet.groupTextOffsetY end,
					tooltip = "Image's tooltip text.",
					width = "full",
				},
				{
					type = "colorpicker",
					name = "Group Icon Dead Color",
					tooltip = "Group icon dead color",
					getFunc = function() return RMM.mainSet.groupDeadColor.r, RMM.mainSet.groupDeadColor.g, RMM.mainSet.groupDeadColor.b, RMM.mainSet.groupDeadColor.a end,
					setFunc = function(r,g,b,a) RMM.mainSet.groupDeadColor = {["r"] = r, ["g"] = g, ["b"] = b, ["a"] = a} end,
					default = RMM.mainDefaults.groupDeadColor,
					width = "full",
				},
			},
		},
		{
			type = "submenu",
			name = "|cFFFFB0Group Leader Custom Icon",
			tooltip = "Set color and size for group leader icon.",
			controls = {
				{
					type = "colorpicker",
					name = "Groupleader Icon Color",
					tooltip = "Groupleader icon color.",
					getFunc = function() return RMM.mainSet.groupLeaderColor.r, RMM.mainSet.groupLeaderColor.g, RMM.mainSet.groupLeaderColor.b, RMM.mainSet.groupLeaderColor.a end,
					setFunc = function(r,g,b,a) RMM.mainSet.groupLeaderColor = {["r"] = r, ["g"] = g, ["b"] = b, ["a"] = a} end,
					default = RMM.mainDefaults.groupLeaderColor,
					width = "half",
				},
				{
					type = "slider",
					name = "Groupleader Icon Size",
					tooltip = "Groupleader icon size.",
					min = 1,
					max = 32,
					step = 1,
					getFunc = function() return RMM.mainSet.groupLeaderSize end,
					setFunc = function(value) RMM.mainSet.groupLeaderSize = value end,
					default = RMM.mainDefaults.groupLeaderSize,
					width = "half",
				},
				{
					type = "colorpicker",
					name = "Groupleader Icon Text Color",
					tooltip = "Groupleader icon text color.",
					getFunc = function() return RMM.mainSet.groupLeaderTextColor.r, RMM.mainSet.groupLeaderTextColor.g, RMM.mainSet.groupLeaderTextColor.b, RMM.mainSet.groupLeaderTextColor.a end,
					setFunc = function(r,g,b,a) RMM.mainSet.groupLeaderTextColor = {["r"] = r, ["g"] = g, ["b"] = b, ["a"] = a} end,
					default = RMM.mainDefaults.groupLeaderTextColor,
					width = "half",
				},
				{
					type = "slider",
					name = "Groupleader Icon Text Size",
					tooltip = "Groupleader icon text size.",
					min = 1,
					max = 32,
					step = 1,
					getFunc = function() return RMM.mainSet.groupLeaderTextSize end,
					setFunc = function(value) RMM.mainSet.groupLeaderTextSize = value end,
					default = RMM.mainDefaults.groupLeaderTextSize,
					width = "half",
				},
				{
					type = "slider",
					name = "Group Leader Icon Text Offset",
					tooltip = "Group leader icon text size.",
					min = -8,
					max = 8,
					step = 0.125,
					getFunc = function() return RMM.mainSet.groupLeaderTextOffsetX end,
					setFunc = function(value) RMM.mainSet.groupLeaderTextOffsetX = value end,
					default = RMM.mainDefaults.groupLeaderTextOffsetX,
					width = "half",
				},
				{
					type = "slider",
					name = "Group Leader Icon Text Offset",
					tooltip = "Group leader icon text offset.",
					min = -8,
					max = 8,
					step = 0.125,
					getFunc = function() return RMM.mainSet.groupLeaderTextOffsetY end,
					setFunc = function(value) RMM.mainSet.groupLeaderTextOffsetY = value end,
					default = RMM.mainDefaults.groupLeaderTextOffsetY,
					width = "half",
				},
				{
					type = "textureAndLabel",
					image = "RadarMiniMap/asset/dot.dds",
					getImageColor = function() return RMM.mainSet.groupLeaderColor.r, RMM.mainSet.groupLeaderColor.g, RMM.mainSet.groupLeaderColor.b, RMM.mainSet.groupLeaderColor.a end,
					getImageWidth = function() return RMM.mainSet.groupLeaderSize end,
					getImageHeight = function() return RMM.mainSet.groupLeaderSize end,
					labelEnabled = true,
					label = "1",
					labelFont = "EsoUI/Common/Fonts/univers55.otf",
					getLabelFontSize = function() return RMM.mainSet.groupLeaderTextSize end,
					labelFontStyle = "none",
					getLabelColor = function() return RMM.mainSet.groupLeaderTextColor.r, RMM.mainSet.groupLeaderTextColor.g, RMM.mainSet.groupLeaderTextColor.b, RMM.mainSet.groupLeaderTextColor.a end,
					getLabelFontOffsetX = function() return RMM.mainSet.groupLeaderTextOffsetX end,
					getLabelFontOffsetY = function() return RMM.mainSet.groupLeaderTextOffsetY end,
					tooltip = "Image's tooltip text.",
					width = "full",
				},
				{
					type = "colorpicker",
					name = "Group Leader Icon Dead Color",
					tooltip = "Group leader icon dead color",
					getFunc = function() return RMM.mainSet.groupLeaderDeadColor.r, RMM.mainSet.groupLeaderDeadColor.g, RMM.mainSet.groupLeaderDeadColor.b, RMM.mainSet.groupLeaderDeadColor.a end,
					setFunc = function(r,g,b,a) RMM.mainSet.groupLeaderDeadColor = {["r"] = r, ["g"] = g, ["b"] = b, ["a"] = a} end,
					default = RMM.mainDefaults.groupLeaderDeadColor,
					width = "full",
				},
			},
		},
		{
			type = "submenu",
			name = "|cFFFFB0Quest Border Icon",
			tooltip = "Set color and size for quest border icon.",
			controls = {
				{
					type = "checkbox",
					name = "Border Quest Icon",
					tooltip = "Border quest icon.",
					getFunc = function() return RMM.mainSet.borderQuest end,
					setFunc = function(value) RMM.mainSet.borderQuest = value end,
					default = RMM.mainDefaults.borderQuest,
					width = "half",
				},
				{
					type = "slider",
					name = "Quest Border Icon Size",
					tooltip = "Quest icon size.",
					min = 1,
					max = 32,
					step = 1,
					getFunc = function() return RMM.mainSet.borderQuestSize end,
					setFunc = function(value) RMM.mainSet.borderQuestSize = value end,
					default = RMM.mainDefaults.borderQuestSize,
					width = "half",
				},
			},
		},
		{
			type = "submenu",
			name = "|cFFFFB0Ping Border Icon",
			tooltip = "Set color and size for Ping Border Icon.",
			controls = {
				{
					type = "checkbox",
					name = "Border Ping Icon",
					tooltip = "Border ping icon.",
					getFunc = function() return RMM.mainSet.borderPing end,
					setFunc = function(value) RMM.mainSet.borderPing = value end,
					default = RMM.mainDefaults.borderPing,
					width = "half",
				},
				{
					type = "slider",
					name = "Ping Border Icon Size",
					tooltip = "Ping icon size.",
					min = 1,
					max = 32,
					step = 1,
					getFunc = function() return RMM.mainSet.borderPingSize end,
					setFunc = function(value) RMM.mainSet.borderPingSize = value end,
					default = RMM.mainDefaults.borderPingSize,
					width = "half",
				},
			},
		},
		{
			type = "submenu",
			name = "|cFFFFB0Keep Links",
			tooltip = "Set color and size for Ping Border Icon.",
			controls = {
				{
					type = "checkbox",
					name = "Keep Links",
					tooltip = "Show/Hide keep links.",
					getFunc = function() return RMM.mainSet.linkEnabled end,
					setFunc = function(value) RMM.mainSet.linkEnabled = value end,
					default = RMM.mainDefaults.linkEnabled,
					width = "half",
				},
				{
					type = "slider",
					name = "Keep Link Thick",
					tooltip = "Set keep link thick.",
					min = 1,
					max = 20,
					step = 1,
					getFunc = function() return RMM.mainSet.linkThick end,
					setFunc = function(value) RMM.mainSet.linkThick = value end,
					default = RMM.mainDefaults.linkThick,
					width = "half",
				},
			},
		},
		{
			type = "submenu",
			name = "|cFFFFB0Advanced",
			tooltip = "Advanced settings.",
			controls = {
				{
					type = "slider",
					name = "Position Update Rate",
					tooltip = "Position update rate. (ms between update)",
					min = 5,
					max = 1000,
					step = 1,
					getFunc = function() return RMM.mainSet.posUpdateRate end,
					setFunc = function(value)
						RMM.mainSet.posUpdateRate = value
						RMM.RegisterForUpdate(true, "RMM_OnPosUpdate", RMM.mainSet.posUpdateRate, RMM.OnPosUpdate)
					end,
					default = RMM.mainDefaults.posUpdateRate,
					width = "half",
				},
				{
					type = "slider",
					name = "Link Update Rate",
					tooltip = "Link update rate. (ms between update)",
					min = 50,
					max = 5000,
					step = 1,
					getFunc = function() return RMM.mainSet.linkUpdateRate end,
					setFunc = function(value)
						RMM.mainSet.linkUpdateRate = value
						RMM.RegisterForUpdate(true, "RMM_OnLinkUpdate", RMM.mainSet.linkUpdateRate, RMM.OnLinkUpdate)
					end,
					default = RMM.mainDefaults.linkUpdateRate,
					width = "half",
				},
				{
					type = "slider",
					name = "Group Update Rate",
					tooltip = "Group update rate. (ms between update)",
					min = 5,
					max = 1000,
					step = 1,
					getFunc = function() return RMM.mainSet.groupUpdateRate end,
					setFunc = function(value)
						RMM.mainSet.groupUpdateRate = value
						RMM.RegisterForUpdate(true, "RMM_OnGroupUpdate", RMM.mainSet.groupUpdateRate, RMM.OnGroupUpdate)
					end,
					default = RMM.mainDefaults.groupUpdateRate,
					width = "half",
				},
				{
					type = "slider",
					name = "Map To Player Position Update Rate",
					tooltip = "Map to player position update rate. (ms between update)",
					min = 500,
					max = 5000,
					step = 1,
					getFunc = function() return RMM.mainSet.smtplUpdateRate end,
					setFunc = function(value)
						RMM.mainSet.smtplUpdateRate = value
						RMM.RegisterForUpdate(true, "RMM_OnSMTPLUpdate", RMM.mainSet.smtplUpdateRate, function() if not RMM.c:IsHidden() then SetMapToPlayerLocation() end end)
					end,
					default = RMM.mainDefaults.smtplUpdateRate,
					width = "half",
				},
			},
		},
	}
end

function RMM.GetTextureChoices(name)
	
	local list = {}
	
	if name == "Wheel Texture" then
		for k,v in pairs(RMM.textures) do
			for kk,vv in pairs(RMM.textures[k].wheel) do
				table.insert(list, k.."~"..kk)
			end
		end
	end
	
	if name == "Overlay Texture" then
		for k,v in pairs(RMM.textures) do
			for kk,vv in pairs(RMM.textures[k].overlay) do
				table.insert(list, k.."~"..kk)
			end
		end
	end
	
	return list
	
end

function RMM.GetFontChoices(name)
	
	local list = {}
	
	if name == "Fonts" then
		for k,v in pairs(RMM.fonts) do
			table.insert(list, k)
		end
	end
	
	if name == "FontTypes" then
		for k,v in pairs(RMM.fontTypes) do
			table.insert(list, k)
		end
	end
	
	return list
	
end

RMM.textures = {
	["RMM"] = {
		["wheel"] = {["default"] = "RadarMiniMap/asset/wheel.dds"},
		["overlay"] = {["default"] = "RadarMiniMap/asset/overlay.dds"}
	}
}

RMM.fonts = {}
RMM.fonts["ProseAntique"] = "EsoUI/Common/Fonts/ProseAntiquePSMT.otf"
RMM.fonts["Arial Narrow"] = "EsoUI/Common/Fonts/arialn.ttf"
RMM.fonts["Consolas"] = "EsoUI/Common/Fonts/consola.ttf"
RMM.fonts["ESO Cartographer"] = "EsoUI/Common/Fonts/esocartographer-bold.otf"
RMM.fonts["Fontin Bold"] = "EsoUI/Common/Fonts/fontin_sans_b.otf"
RMM.fonts["Fontin Italic"] = "EsoUI/Common/Fonts/fontin_sans_i.otf"
RMM.fonts["Fontin Regular"] = "EsoUI/Common/Fonts/fontin_sans_r.otf"
RMM.fonts["Fontin SmallCaps"] = "EsoUI/Common/Fonts/fontin_sans_sc.otf"
RMM.fonts["Skyrim Handwritten"] = "EsoUI/Common/Fonts/Handwritten_Bold.otf"
RMM.fonts["Trajan Pro"] = "EsoUI/Common/Fonts/trajanpro-regular.otf"
RMM.fonts["Univers 55"] = "EsoUI/Common/Fonts/univers55.otf"
RMM.fonts["Univers 57"] = "EsoUI/Common/Fonts/univers57.otf"
RMM.fonts["Univers 67"] = "EsoUI/Common/Fonts/univers67.otf"

RMM.fontTypes = {}
RMM.fontTypes["none"] = "none"
RMM.fontTypes["Soft Shadow Thin"] = "soft-shadow-thin"
RMM.fontTypes["Soft Shadow Thick"] = "soft-shadow-thick"
RMM.fontTypes["Shadow"] = "shadow"

