--[[----------------------------------------------------------
	RadarMiniMap Pins
  ]]-----------------------------------------------------------

------------------Global Variables------------------
  
RMM.pins = {}
RMM.pinAnimations = {}

 ------------------Local Functions------------------

local function ResetPin(mmPin)
	
	if not mmPin then return end

	mmPin:SetHidden(true)
	mmPin:SetTexture("")
	mmPin:SetDimensions(0, 0)
	mmPin:SetColor(0,0,0,0)
	mmPin.activ = false
	mmPin.blobSize = nil
    mmPin.blobTexture = nil
	mmPin.radius = nil
	mmPin.defaultBlobTexture = nil
	
	if mmPin.animation then
		RMM.pinAnimations[mmPin.animation] = nil
		mmPin.animation = nil
	end

end

local function UpdateBlob(mmPin)

    local lastTexture = mmPin.blobTexture
 
	if mmPin.bordered then
		mmPin.blobTexture = "EsoUI/Art/Compass/quest_icon_assisted.dds"
		mmPin:SetDimensions(RMM.mainSet.borderQuestSize, RMM.mainSet.borderQuestSize)
		mmPin.blobSize = nil
	else
		mmPin.blobTexture = mmPin.defaultBlobTexture
		mmPin.blobSize = mmPin.radius * 2 * RMM.map[RMM.mapName].mapSizeWidth * RMM.mapZoom
	end
 
	if lastTexture ~= mmPin.blobTexture then
		mmPin:SetTexture(mmPin.blobTexture)
		RMM.blobChanged = true
	end

end
 
------------------Global Functions------------------

function RMM.CreatePin(self, lookupType, majorIndex, keyIndex, pinKey)
	
	if not RMM.mainSet.pinEnabled then return end
	
	local keys = {["lookupType"] = lookupType, ["majorIndex"] = majorIndex, ["keyIndex"] = keyIndex, ["pinKey"] = pinKey}
	local pin = self:GetExistingObject(pinKey)
	
	if pin and pinKey then
		if pin:IsAssisted() then RMM.CreatePinAssisted(pin, keys)
		elseif pin:IsAvAObjective() then RMM.CreatePinAvAObjective(pin, keys)
		elseif pin:IsAvARespawn() then RMM.CreatePinAvARespown(pin, keys)
		elseif pin:IsFastTravelKeep() then RMM.CreatePinFastTravelKeep(pin, keys)
		elseif pin:IsFastTravelWayShrine() then RMM.CreatePinFastTravelWayShire(pin, keys)
		elseif pin:IsForwardCamp() then RMM.CreatePinForwardCamp(pin, keys)
		elseif pin:IsKeep() then RMM.CreatePinKeep(pin,keys)
		elseif pin:IsKillLocation() then RMM.CreatePinKillLocation(pin, keys)
		elseif pin:IsLocation() then RMM.CreatePinLocation(pin, keys)
		elseif pin:IsMapPing() then RMM.CreatePinMapPing(pin, keys)
		elseif pin:IsPOI() then RMM.CreatePinPOI(pin, keys)
		elseif pin:IsQuest() then RMM.CreatePinQuest(pin, keys)
		elseif pin:IsUnderAttackPin() then RMM.CreatePinUnderAttackPin(pin, keys)
		elseif pin:IsGroup() then RMM.CreatePinGroup(pin, keys)
		else RMM.CreatePinCustomPin(pin, keys)
		end
	end

end

function RMM.RemovePins(self, lookupType, majorIndex, keyIndex)

	local lookupTable = self.m_keyToPinMapping[lookupType]
	
    if majorIndex then
        local keys = lookupTable[majorIndex]
        if keys then
            if keyIndex then
                local pinKey = keys[keyIndex]
                if pinKey then
					ResetPin(RMM.pins[pinKey])
                end
            else
                for _, pinKey in pairs(keys) do
                    ResetPin(RMM.pins[pinKey])
                end
            end
        end
    else
        for _, keys in pairs(lookupTable) do
            for _, pinKey in pairs(keys) do
                ResetPin(RMM.pins[pinKey])
            end        
        end
    end	

end

function RMM.SetPinPos(rotate)

	if not RMM.mainSet.pinEnabled then return end
	
	for _,mmPin in pairs(RMM.pins) do
		
		if mmPin.activ then
		
			local scX, scY = RMM.c.map:GetDimensions()
			local x = 0
			local y = 0
			local z = 0
			local xx = 0
			local yy = 0
			
			if RMM.mainSet.squareMap then
				xx = (scX / 2) + RMM.mainSet.pixelBorder
				yy = (scY / 2) + RMM.mainSet.pixelBorder
			else
				xx = (scX / 2) + ((scX / 2) * (RMM.mainSet.percentBorder / 100))
				yy = (scY / 2) + ((scY / 2) * (RMM.mainSet.percentBorder / 100))
			end
			
			if rotate then
				local fx = (mmPin.normX * RMM.map[RMM.mapName]["mapSizeWidth"] * RMM.mapZoom) - RMM.player.posX
				local fy = (mmPin.normY * RMM.map[RMM.mapName]["mapSizeHigh"] * RMM.mapZoom) - RMM.player.posY
				x = (math.cos(-RMM.player.heading) * fx) - (math.sin(-RMM.player.heading) * fy)
				y = (math.sin(-RMM.player.heading) * fx) + (math.cos(-RMM.player.heading) * fy)
				z = math.sqrt((x^2)+(y^2))
			else
				local fx = (mmPin.normX * RMM.map[RMM.mapName]["mapSizeWidth"] * RMM.mapZoom) - RMM.player.posX
				local fy = (mmPin.normY * RMM.map[RMM.mapName]["mapSizeHigh"] * RMM.mapZoom) - RMM.player.posY
				x = (math.cos(0.0001) * fx) - (math.sin(0.00001) * fy)
				y = (math.sin(0.0001) * fx) + (math.cos(0.00001) * fy)
				z = math.sqrt((x^2)+(y^2))
			end
			
			if ZO_MapPin.ASSISTED_PIN_TYPES[mmPin.pinType] and RMM.mainSet.borderQuest then --if active quest, active border
				if not RMM.mainSet.squareMap then
					if z > xx then
						if not mmPin.bordered then
							mmPin.bordered = true
							if mmPin.blobTexture then
                                UpdateBlob(mmPin)
                            else
								mmPin:SetDimensions(RMM.mainSet.borderQuestSize, RMM.mainSet.borderQuestSize)
							end
						end
						x = (xx/z)*x
						y = (xx/z)*y
					else
						if mmPin.bordered then
							mmPin.bordered = false
							if mmPin.blobTexture then
                                UpdateBlob(mmPin)
                            else
								mmPin:SetDimensions(mmPin.defaultSize * RMM.mainSet.pinSize, mmPin.defaultSize * RMM.mainSet.pinSize)
							end
						end
					end
				else
					if x > xx or x < -xx or y > yy or y < -yy then
						if not mmPin.bordered then
							mmPin.bordered = true
							if mmPin.blobTexture then
                                UpdateBlob(mmPin)
                            else
								mmPin:SetDimensions(RMM.mainSet.borderQuestSize, RMM.mainSet.borderQuestSize)
							end
						end
						if x > xx or y > yy then
							if x/xx < y/yy then
								x = yy / y * x
								y = yy
							end
							if y/yy < x/xx then
								y = xx / x * y
								x = xx
							end
						end
						if x < -xx or y < -yy then
							if x/xx > y/yy then
								x = -yy / y * x
								y = -yy
							end		
							if y/yy > x/xx then
								y = -xx / x * y
								x = -xx
							end
						end
					else
						if mmPin.bordered then
							mmPin.bordered = false
							if mmPin.blobTexture then
                                UpdateBlob(mmPin)
                            else
								mmPin:SetDimensions(mmPin.defaultSize * RMM.mainSet.pinSize, mmPin.defaultSize * RMM.mainSet.pinSize)
							end
						end
					end
				end	
			elseif ZO_MapPin.MAP_PING_PIN_TYPES[mmPin.pinType] and RMM.mainSet.borderPing then --if ping
				if not RMM.mainSet.squareMap then
					if z > xx then
						if not mmPin.bordered then
							mmPin:SetDimensions(RMM.mainSet.borderPingSize, RMM.mainSet.borderPingSize)
							mmPin.bordered = true
						end
						x = (xx/z)*x
						y = (xx/z)*y
					else
						if mmPin.bordered then
							mmPin:SetDimensions(mmPin.defaultSize * RMM.mainSet.pinSize * 0.75, mmPin.defaultSize * RMM.mainSet.pinSize * 0.75)
							mmPin.bordered = false
						end
					end
				else
					if x > xx or x < -xx or y > yy or y < -yy then
						if not mmPin.bordered then
							mmPin:SetDimensions(RMM.mainSet.borderPingSize, RMM.mainSet.borderPingSize)
							mmPin.bordered = true
						end
						if x > xx or y > yy then
							if x/xx < y/yy then
								x = yy / y * x
								y = yy
							end
							if y/yy < x/xx then
								y = xx / x * y
								x = xx
							end
						end
						if x < -xx or y < -yy then
							if x/xx > y/yy then
								x = -yy / y * x
								y = -yy
							end		
							if y/yy > x/xx then
								y = -xx / x * y
								x = -xx
							end
						end
					else
						if mmPin.bordered then
							mmPin:SetDimensions(mmPin.defaultSize * RMM.mainSet.pinSize * 0.75, mmPin.defaultSize * RMM.mainSet.pinSize * 0.75)
							mmPin.bordered = false
						end
					end
				end
			end
			
			if (mmPin.blobSize and RMM.zoomChanged) or (mmPin.blobSize and RMM.blobChanged) or mmPin.blobSize == 0 then
				mmPin.blobSize = mmPin.radius * 2 * RMM.map[RMM.mapName].mapSizeWidth * RMM.mapZoom
				mmPin:SetDimensions(mmPin.blobSize, mmPin.blobSize)
				RMM.blobChanged = false
			end
			
			mmPin:ClearAnchors()
			mmPin:SetAnchor(CENTER, RMM.c, CENTER, x, y)
		end
		
	end
	RMM.zoomChanged = false
end