--[[----------------------------------------------------------
	RadarMiniMap Pins Create
  ]]-----------------------------------------------------------

------------------Local Functions------------------

local function SetOwner(self, owner, point, offsetX, offsetY)
	self:ClearAnchors()
	if(point == TOPLEFT) then
		self:SetAnchor(TOPLEFT, owner, TOPRIGHT, offsetX, offsetY)
	else
		self:SetAnchor(TOPRIGHT, owner, TOPLEFT, offsetX, offsetY)
	end
end

local function CreatePinControl(pinKey)
	
	local mmPin
	
	if not WINDOW_MANAGER:GetControlByName("RMM_PIN_"..pinKey) then
		mmPin = WINDOW_MANAGER:CreateControl("RMM_PIN_"..pinKey, RMM.c.map, CT_TEXTURE)
	else
		mmPin = WINDOW_MANAGER:GetControlByName("RMM_PIN_"..pinKey)
	end
	
	return mmPin
	
end


local function GetIcon(pin)

	local texture = "/esoui/art/icons/icon_missing.dds"
	local pinData = pin.PIN_DATA[pin.m_PinType]
	
	if pin.pinBlobKey ~= nil then
		texture = pin.pinBlobTexture
	elseif type(pinData.texture) == 'string' then
		texture = pinData.texture
	elseif type(pinData.texture) == 'function' then
		texture = pinData.texture(pin)
	end
	
	return texture

end

local function SetPin(pin, keys)
	
	local pinData = pin.PIN_DATA[pin.m_PinType]
	local mmPin = CreatePinControl(keys.pinKey)
	
	mmPin.defaultSize = pinData.size or pinData.minSize
	mmPin.pinType = pin.m_PinType
	mmPin.normX = pin.normalizedX
	mmPin.normY = pin.normalizedY
	mmPin.bordered = false
	mmPin.activ = true
	mmPin:SetTexture(GetIcon(pin))
	mmPin:SetDimensions(mmPin.defaultSize * RMM.mainSet.pinSize, mmPin.defaultSize * RMM.mainSet.pinSize)
	mmPin:SetColor(1,1,1,1)
	mmPin:SetDrawLayer(2)
	mmPin:SetDrawLevel(pinData.level)
	mmPin:SetHidden(false)
	mmPin:SetMouseEnabled(true)
	
	return mmPin

end
  
------------------Global Functions------------------

function RMM.CreatePinAssisted(pin, keys)
	
	local mmPin = SetPin(pin, keys)
	
	if pin.pinBlobKey then
		mmPin.radius = pin.radius
        mmPin.blobSize = RMM.map[RMM.mapName] and pin.radius * 2 * RMM.map[RMM.mapName].mapSizeWidth * RMM.mapZoom or 0
        mmPin.blobTexture = pin.pinBlobTexture
		mmPin.defaultBlobTexture = pin.pinBlobTexture
        local size = mmPin.blobSize
		mmPin:SetDimensions(size, size)
    end
	
	local pinTooltipInfo = ZO_MapPin.TOOLTIP_CREATORS[pin.m_PinType]
	
	mmPin:SetHandler("OnMouseEnter",
	function()
		RMM.OnMouseEnter()
		if not RMM.mainSet.tooltipsEnabled then return end
		if pinTooltipInfo.tooltip then
			if pinTooltipInfo.tooltip == ZO_KeepTooltip then
				ZO_KeepTooltip:SetHidden(false)
				SetOwner(ZO_KeepTooltip, RMM.c.menuv, RMM.tooltipAnchor, 0, 0)
			else
				InitializeTooltip(pinTooltipInfo.tooltip, RMM.c.menuv, RMM.tooltipAnchor, 0, 0)
			end
		end
		pinTooltipInfo.creator(pin)
	end)
	
	mmPin:SetHandler("OnMouseExit",
	function()
		RMM.OnMouseExit()
		if pinTooltipInfo.tooltip then
			if pinTooltipInfo.tooltip == ZO_KeepTooltip then
				ZO_KeepTooltip:SetHidden(true)
			else
				ClearTooltip(pinTooltipInfo.tooltip)
			end
		end
	end)
	
	mmPin:SetHandler("OnMouseUp",
	function()
		local questIndex = pin:GetQuestIndex()
        QUEST_TRACKER:ForceAssist(questIndex)
	end)
	
	RMM.pins[keys.pinKey] = mmPin
	
end

function RMM.CreatePinAvAObjective(pin, keys)
	
	local mmPin = SetPin(pin, keys)
	
	local pinTooltipInfo = ZO_MapPin.TOOLTIP_CREATORS[pin.m_PinType]
	
	mmPin:SetHandler("OnMouseEnter",
	function()
		RMM.OnMouseEnter()
		if not RMM.mainSet.tooltipsEnabled then return end
		if pinTooltipInfo.tooltip then
			if pinTooltipInfo.tooltip == ZO_KeepTooltip then
				ZO_KeepTooltip:SetHidden(false)
				SetOwner(ZO_KeepTooltip, RMM.c.menuv, RMM.tooltipAnchor, 0, 0)
			else
				InitializeTooltip(pinTooltipInfo.tooltip, RMM.c.menuv, RMM.tooltipAnchor, 0, 0)
			end
		end
		pinTooltipInfo.creator(pin)
	end)
	
	mmPin:SetHandler("OnMouseExit",
	function()
		RMM.OnMouseExit()
		if pinTooltipInfo.tooltip then
			if pinTooltipInfo.tooltip == ZO_KeepTooltip then
				ZO_KeepTooltip:SetHidden(true)
			else
				ClearTooltip(pinTooltipInfo.tooltip)
			end
		end
	end)
	
	RMM.pins[keys.pinKey] = mmPin
	
end

function RMM.CreatePinAvARespown(pin, keys)
	
	local mmPin = SetPin(pin, keys)
	
	local pinTooltipInfo = ZO_MapPin.TOOLTIP_CREATORS[pin.m_PinType]
	
	mmPin:SetHandler("OnMouseEnter",
	function()
		RMM.OnMouseEnter()
		if not RMM.mainSet.tooltipsEnabled then return end
		if pinTooltipInfo.tooltip then
			if pinTooltipInfo.tooltip == ZO_KeepTooltip then
				ZO_KeepTooltip:SetHidden(false)
				SetOwner(ZO_KeepTooltip, RMM.c.menuv, RMM.tooltipAnchor, 0, 0)
			else
				InitializeTooltip(pinTooltipInfo.tooltip, RMM.c.menuv, RMM.tooltipAnchor, 0, 0)
			end
		end
		pinTooltipInfo.creator(pin)
	end)
	
	mmPin:SetHandler("OnMouseExit",
	function()
		RMM.OnMouseExit()
		if pinTooltipInfo.tooltip then
			if pinTooltipInfo.tooltip == ZO_KeepTooltip then
				ZO_KeepTooltip:SetHidden(true)
			else
				ClearTooltip(pinTooltipInfo.tooltip)
			end
		end
	end)
	
	RMM.pins[keys.pinKey] = mmPin
	
end

function RMM.CreatePinFastTravelKeep(pin, keys)
	
	local mmPin = SetPin(pin, keys)
	
	local pinTooltipInfo = ZO_MapPin.TOOLTIP_CREATORS[pin.m_PinType]
	
	mmPin:SetHandler("OnMouseEnter",
	function()
		RMM.OnMouseEnter()
		if not RMM.mainSet.tooltipsEnabled then return end
		if pinTooltipInfo.tooltip then
			if pinTooltipInfo.tooltip == ZO_KeepTooltip then
				ZO_KeepTooltip:SetHidden(false)
				SetOwner(ZO_KeepTooltip, RMM.c.menuv, RMM.tooltipAnchor, 0, 0)
			else
				InitializeTooltip(pinTooltipInfo.tooltip, RMM.c.menuv, RMM.tooltipAnchor, 0, 0)
			end
		end
		pinTooltipInfo.creator(pin)
	end)
	
	mmPin:SetHandler("OnMouseExit",
	function()
		RMM.OnMouseExit()
		if pinTooltipInfo.tooltip then
			if pinTooltipInfo.tooltip == ZO_KeepTooltip then
				ZO_KeepTooltip:SetHidden(true)
			else
				ClearTooltip(pinTooltipInfo.tooltip)
			end
		end
	end)
	
	RMM.pins[keys.pinKey] = mmPin
	
end

function RMM.CreatePinFastTravelWayShire(pin, keys)
	
	local mmPin = SetPin(pin, keys)
	
	local pinTooltipInfo = ZO_MapPin.TOOLTIP_CREATORS[pin.m_PinType]
	
	mmPin:SetHandler("OnMouseEnter",
	function()
		RMM.OnMouseEnter()
		if not RMM.mainSet.tooltipsEnabled then return end
		if pinTooltipInfo.tooltip then
			if pinTooltipInfo.tooltip == ZO_KeepTooltip then
				ZO_KeepTooltip:SetHidden(false)
				SetOwner(ZO_KeepTooltip, RMM.c.menuv, RMM.tooltipAnchor, 0, 0)
			else
				InitializeTooltip(pinTooltipInfo.tooltip, RMM.c.menuv, RMM.tooltipAnchor, 0, 0)
			end
		end
		pinTooltipInfo.creator(pin)
	end)
	
	mmPin:SetHandler("OnMouseExit",
	function()
		RMM.OnMouseExit()
		if pinTooltipInfo.tooltip then
			if pinTooltipInfo.tooltip == ZO_KeepTooltip then
				ZO_KeepTooltip:SetHidden(true)
			else
				ClearTooltip(pinTooltipInfo.tooltip)
			end
		end
	end)
	
	mmPin:SetHandler("OnMouseUp",
	function()
		if not IsInCampaign() then
			local nodeIndex = pin:GetFastTravelNodeIndex()
			ZO_Dialogs_ReleaseDialog("FAST_TRAVEL_CONFIRM")
			local name = select(2, GetFastTravelNodeInfo(nodeIndex))
			ZO_Dialogs_ShowDialog("FAST_TRAVEL_CONFIRM", {nodeIndex = nodeIndex}, {mainTextParams = {name}})
		end
	end)
	
	RMM.pins[keys.pinKey] = mmPin
	
end

function RMM.CreatePinForwardCamp(pin, keys)
	
	local mmPin = SetPin(pin, keys)
	
	local pinTooltipInfo = ZO_MapPin.TOOLTIP_CREATORS[pin.m_PinType]
	
	mmPin:SetHandler("OnMouseEnter",
	function()
		RMM.OnMouseEnter()
		if not RMM.mainSet.tooltipsEnabled then return end
		if pinTooltipInfo.tooltip then
			if pinTooltipInfo.tooltip == ZO_KeepTooltip then
				ZO_KeepTooltip:SetHidden(false)
				SetOwner(ZO_KeepTooltip, RMM.c.menuv, RMM.tooltipAnchor, 0, 0)
			else
				InitializeTooltip(pinTooltipInfo.tooltip, RMM.c.menuv, RMM.tooltipAnchor, 0, 0)
			end
		end
		pinTooltipInfo.creator(pin)
	end)
	
	mmPin:SetHandler("OnMouseExit",
	function()
		RMM.OnMouseExit()
		if pinTooltipInfo.tooltip then
			if pinTooltipInfo.tooltip == ZO_KeepTooltip then
				ZO_KeepTooltip:SetHidden(true)
			else
				ClearTooltip(pinTooltipInfo.tooltip)
			end
		end
	end)
	
	RMM.pins[keys.pinKey] = mmPin
	
end

function RMM.CreatePinKeep(pin, keys)
	
	local mmPin = SetPin(pin, keys)
	
	local pinTooltipInfo = ZO_MapPin.TOOLTIP_CREATORS[pin.m_PinType]
	
	mmPin:SetHandler("OnMouseEnter",
	function()
		RMM.OnMouseEnter()
		if not RMM.mainSet.tooltipsEnabled then return end
		if pinTooltipInfo.tooltip then
			if pinTooltipInfo.tooltip == ZO_KeepTooltip then
				ZO_KeepTooltip:SetHidden(false)
				SetOwner(ZO_KeepTooltip, RMM.c.menuv, RMM.tooltipAnchor, 0, 0)
			else
				InitializeTooltip(pinTooltipInfo.tooltip, RMM.c.menuv, RMM.tooltipAnchor, 0, 0)
			end
		end
		pinTooltipInfo.creator(pin)
	end)
	
	mmPin:SetHandler("OnMouseExit",
	function()
		RMM.OnMouseExit()
		if pinTooltipInfo.tooltip then
			if pinTooltipInfo.tooltip == ZO_KeepTooltip then
				ZO_KeepTooltip:SetHidden(true)
			else
				ClearTooltip(pinTooltipInfo.tooltip)
			end
		end
	end)
	
	RMM.pins[keys.pinKey] = mmPin
	
end

function RMM.CreatePinKillLocation(pin, keys)
	
	local mmPin = SetPin(pin, keys)
	
	local pinTooltipInfo = ZO_MapPin.TOOLTIP_CREATORS[pin.m_PinType]
	
	mmPin:SetHandler("OnMouseEnter",
	function()
		RMM.OnMouseEnter()
		if not RMM.mainSet.tooltipsEnabled then return end
		if pinTooltipInfo.tooltip then
			if pinTooltipInfo.tooltip == ZO_KeepTooltip then
				ZO_KeepTooltip:SetHidden(false)
				SetOwner(ZO_KeepTooltip, RMM.c.menuv, RMM.tooltipAnchor, 0, 0)
			else
				InitializeTooltip(pinTooltipInfo.tooltip, RMM.c.menuv, RMM.tooltipAnchor, 0, 0)
			end
		end
		pinTooltipInfo.creator(pin)
	end)
	
	mmPin:SetHandler("OnMouseExit",
	function()
		RMM.OnMouseExit()
		if pinTooltipInfo.tooltip then
			if pinTooltipInfo.tooltip == ZO_KeepTooltip then
				ZO_KeepTooltip:SetHidden(true)
			else
				ClearTooltip(pinTooltipInfo.tooltip)
			end
		end
	end)
	
	RMM.pins[keys.pinKey] = mmPin
	
end

function RMM.CreatePinLocation(pin, keys)
	
	local mmPin = SetPin(pin, keys)
	
	local pinTooltipInfo = ZO_MapPin.TOOLTIP_CREATORS[pin.m_PinType]
	
	mmPin:SetHandler("OnMouseEnter",
	function()
		RMM.OnMouseEnter()
		if not RMM.mainSet.tooltipsEnabled then return end
		if pinTooltipInfo.tooltip then
			if pinTooltipInfo.tooltip == ZO_KeepTooltip then
				ZO_KeepTooltip:SetHidden(false)
				SetOwner(ZO_KeepTooltip, RMM.c.menuv, RMM.tooltipAnchor, 0, 0)
			else
				InitializeTooltip(pinTooltipInfo.tooltip, RMM.c.menuv, RMM.tooltipAnchor, 0, 0)
			end
		end
		pinTooltipInfo.creator(pin)
	end)
	
	mmPin:SetHandler("OnMouseExit",
	function()
		RMM.OnMouseExit()
		if pinTooltipInfo.tooltip then
			if pinTooltipInfo.tooltip == ZO_KeepTooltip then
				ZO_KeepTooltip:SetHidden(true)
			else
				ClearTooltip(pinTooltipInfo.tooltip)
			end
		end
	end)
	
	RMM.pins[keys.pinKey] = mmPin
	
end

function RMM.CreatePinMapPing(pin, keys)
	
	local mmPin = SetPin(pin, keys)
	
	mmPin:SetTexture("RadarMiniMap/asset/ping.dds")
	
	mmPin:SetTextureCoords(0, 0.25, 0, 1)
	mmPin:SetDimensions(mmPin.defaultSize * RMM.mainSet.pinSize * 0.75, mmPin.defaultSize * RMM.mainSet.pinSize * 0.75)
	if mmPin.pinType == MAP_PIN_TYPE_PING then
		mmPin:SetColor(RMM.mainSet.ping3Color.r,RMM.mainSet.ping3Color.g,RMM.mainSet.ping3Color.b,RMM.mainSet.ping3Color.a)
	elseif mmPin.pinType == MAP_PIN_TYPE_RALLY_POINT then
		mmPin:SetColor(RMM.mainSet.ping2Color.r,RMM.mainSet.ping2Color.g,RMM.mainSet.ping2Color.b,RMM.mainSet.ping2Color.a)
	elseif mmPin.pinType == MAP_PIN_TYPE_PLAYER_WAYPOINT then
		mmPin:SetColor(RMM.mainSet.ping1Color.r,RMM.mainSet.ping1Color.g,RMM.mainSet.ping1Color.b,RMM.mainSet.ping1Color.a)
	else
		mmPin:SetColor(1,1,1,1)
	end
	
	local index = 1
	local function Next(_index)
		index = _index + 1
    end
    table.foreachi( RMM.pinAnimations, Next )
	mmPin.animation = index
	table.insert(RMM.pinAnimations,index,mmPin)
	
	local pinTooltipInfo = ZO_MapPin.TOOLTIP_CREATORS[pin.m_PinType]
	
	mmPin:SetHandler("OnMouseEnter",
	function()
		RMM.OnMouseEnter()
		if not RMM.mainSet.tooltipsEnabled then return end
		if pinTooltipInfo.tooltip then
			if pinTooltipInfo.tooltip == ZO_KeepTooltip then
				ZO_KeepTooltip:SetHidden(false)
				SetOwner(ZO_KeepTooltip, RMM.c.menuv, RMM.tooltipAnchor, 0, 0)
			else
				InitializeTooltip(pinTooltipInfo.tooltip, RMM.c.menuv, RMM.tooltipAnchor, 0, 0)
			end
		end
		pinTooltipInfo.creator(pin)
	end)
	
	mmPin:SetHandler("OnMouseExit",
	function()
		RMM.OnMouseExit()
		if pinTooltipInfo.tooltip then
			if pinTooltipInfo.tooltip == ZO_KeepTooltip then
				ZO_KeepTooltip:SetHidden(true)
			else
				ClearTooltip(pinTooltipInfo.tooltip)
			end
		end
	end)
	
	RMM.pins[keys.pinKey] = mmPin
	
end

function RMM.CreatePinPOI(pin, keys)
	
	local mmPin = SetPin(pin, keys)
	
	local pinTooltipInfo = ZO_MapPin.TOOLTIP_CREATORS[pin.m_PinType]
	
	local function SetObjectiveMessage(pin)
		local poiIndex = pin:GetPOIIndex()
		local zoneIndex = pin:GetPOIZoneIndex()
		
		local poiName, _, poiStartDesc, poiFinishedDesc = GetPOIInfo(zoneIndex, poiIndex)

		InformationTooltip:AddLine(zo_strformat(SI_WORLD_MAP_LOCATION_NAME, poiName), "", ZO_TOOLTIP_DEFAULT_COLOR:UnpackRGB()) 

		local pinType = select(3, GetPOIMapInfo(zoneIndex, poiIndex))
		if pinType == MAP_PIN_TYPE_POI_COMPLETE then
			if poiFinishedDesc ~= "" then InformationTooltip:AddLine(poiFinishedDesc, "", ZO_HIGHLIGHT_TEXT:UnpackRGB()) end
		else
			if poiStartDesc ~= "" then InformationTooltip:AddLine(poiStartDesc, "", ZO_HIGHLIGHT_TEXT:UnpackRGB()) end
		end
	end
	
	mmPin:SetHandler("OnMouseEnter",
	function()
		RMM.OnMouseEnter()
		if not RMM.mainSet.tooltipsEnabled then return end
		InitializeTooltip(InformationTooltip, RMM.c.menuv, RMM.tooltipAnchor, 0, 0)
		SetObjectiveMessage(pin)
	end)
	
	mmPin:SetHandler("OnMouseExit", function() RMM.OnMouseExit(); ClearTooltip(InformationTooltip) end)
	
	RMM.pins[keys.pinKey] = mmPin
	
end

function RMM.CreatePinQuest(pin, keys)
	
	local mmPin = SetPin(pin, keys)
	
	if pin.pinBlobKey then
		mmPin.radius = pin.radius
        mmPin.blobSize = RMM.map[RMM.mapName] and pin.radius * 2 * RMM.map[RMM.mapName].mapSizeWidth * RMM.mapZoom or 0
        mmPin.blobTexture = pin.pinBlobTexture
		mmPin.defaultBlobTexture = pin.pinBlobTexture
        local size = mmPin.blobSize
		mmPin:SetDimensions(size, size)
    end
	
	local pinTooltipInfo = ZO_MapPin.TOOLTIP_CREATORS[pin.m_PinType]
	
	mmPin:SetHandler("OnMouseEnter",
	function()
		RMM.OnMouseEnter()
		if not RMM.mainSet.tooltipsEnabled then return end
		if pinTooltipInfo.tooltip then
			if pinTooltipInfo.tooltip == ZO_KeepTooltip then
				ZO_KeepTooltip:SetHidden(false)
				SetOwner(ZO_KeepTooltip, RMM.c.menuv, RMM.tooltipAnchor, 0, 0)
			else
				InitializeTooltip(pinTooltipInfo.tooltip, RMM.c.menuv, RMM.tooltipAnchor, 0, 0)
			end
		end
		pinTooltipInfo.creator(pin)
	end)
	
	mmPin:SetHandler("OnMouseExit",
	function()
		RMM.OnMouseExit()
		if not RMM.mainSet.tooltipsEnabled then return end
		if pinTooltipInfo.tooltip then
			if pinTooltipInfo.tooltip == ZO_KeepTooltip then
				ZO_KeepTooltip:SetHidden(true)
			else
				ClearTooltip(pinTooltipInfo.tooltip)
			end
		end
	end)
	
	mmPin:SetHandler("OnMouseUp",
	function()
		local questIndex = pin:GetQuestIndex()
        QUEST_TRACKER:ForceAssist(questIndex)
	end)
	
	RMM.pins[keys.pinKey] = mmPin
	
end

function RMM.CreatePinUnderAttackPin(pin, keys)

	local mmPin = SetPin(pin, keys)
	
	local pinTooltipInfo = ZO_MapPin.TOOLTIP_CREATORS[pin.m_PinType]
	
	mmPin:SetHandler("OnMouseEnter",
	function()
		RMM.OnMouseEnter()
		if not RMM.mainSet.tooltipsEnabled then return end
		if pinTooltipInfo.tooltip then
			if pinTooltipInfo.tooltip == ZO_KeepTooltip then
				ZO_KeepTooltip:SetHidden(false)
				SetOwner(ZO_KeepTooltip, RMM.c.menuv, RMM.tooltipAnchor, 0, 0)
			else
				InitializeTooltip(pinTooltipInfo.tooltip, RMM.c.menuv, RMM.tooltipAnchor, 0, 0)
			end
		end
		pinTooltipInfo.creator(pin)
	end)
	
	mmPin:SetHandler("OnMouseExit",
	function()
		RMM.OnMouseExit()
		if pinTooltipInfo.tooltip then
			if pinTooltipInfo.tooltip == ZO_KeepTooltip then
				ZO_KeepTooltip:SetHidden(true)
			else
				ClearTooltip(pinTooltipInfo.tooltip)
			end
		end
	end)
	
	RMM.pins[keys.pinKey] = mmPin
	
end

function RMM.CreatePinGroup(pin, keys)
	--unused
end

function RMM.CreatePinCustomPin(pin, keys)
	
	local mmPin = SetPin(pin, keys)
	
	local pinTooltipInfo = ZO_MapPin.TOOLTIP_CREATORS[pin.m_PinType]
	
	mmPin:SetHandler("OnMouseEnter",
	function()
		RMM.OnMouseEnter()
		if not RMM.mainSet.tooltipsEnabled then return end
		if pinTooltipInfo.tooltip then
			if pinTooltipInfo.tooltip == ZO_KeepTooltip then
				ZO_KeepTooltip:SetHidden(false)
				SetOwner(ZO_KeepTooltip, RMM.c.menuv, RMM.tooltipAnchor, 0, 0)
			else
				InitializeTooltip(pinTooltipInfo.tooltip, RMM.c.menuv, RMM.tooltipAnchor, 0, 0)
			end
		end
		pinTooltipInfo.creator(pin)
	end)
	
	mmPin:SetHandler("OnMouseExit",
	function()
		RMM.OnMouseExit()
		if pinTooltipInfo.tooltip then
			if pinTooltipInfo.tooltip == ZO_KeepTooltip then
				ZO_KeepTooltip:SetHidden(true)
			else
				ClearTooltip(pinTooltipInfo.tooltip)
			end
		end
	end)
	
	if (keys.lookupType):find("^HrvstPin") then
		mmPin:SetDimensions(mmPin.defaultSize * RMM.mainSet.pinSize * RMM.mainSet.harvestMapZoom, mmPin.defaultSize * RMM.mainSet.pinSize * RMM.mainSet.harvestMapZoom)
		mmPin:SetColor(pin.PIN_DATA[pin.m_PinType].color[1], pin.PIN_DATA[pin.m_PinType].color[2], pin.PIN_DATA[pin.m_PinType].color[3], 1)
	end
	
	if keys.lookupType == "HarvensCustomMapPinsType" then
		zo_callLater(function()
			local bg = pin:GetControl():GetNamedChild("Background")
			local texture = bg:GetTextureFileName()
			local r,g,b = bg:GetColor()
			mmPin:SetTexture(bg:GetTextureFileName())
			mmPin:SetColor(r,g,b,1)
		end,5)
	end
	
	RMM.pins[keys.pinKey] = mmPin
	
end